'''_3913.py

CylindricalGearMeshCompoundPowerFlow
'''


from typing import List

from mastapy.system_model.connections_and_sockets.gears import _2018
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.power_flows import _3780
from mastapy.system_model.analyses_and_results.power_flows.compound import _3924
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_MESH_COMPOUND_POWER_FLOW = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.PowerFlows.Compound', 'CylindricalGearMeshCompoundPowerFlow')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGearMeshCompoundPowerFlow',)


class CylindricalGearMeshCompoundPowerFlow(_3924.GearMeshCompoundPowerFlow):
    '''CylindricalGearMeshCompoundPowerFlow

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_GEAR_MESH_COMPOUND_POWER_FLOW

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalGearMeshCompoundPowerFlow.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2018.CylindricalGearMesh':
        '''CylindricalGearMesh: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2018.CylindricalGearMesh)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def connection_design(self) -> '_2018.CylindricalGearMesh':
        '''CylindricalGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2018.CylindricalGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_analysis_cases_ready(self) -> 'List[_3780.CylindricalGearMeshPowerFlow]':
        '''List[CylindricalGearMeshPowerFlow]: 'ConnectionAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConnectionAnalysisCasesReady, constructor.new(_3780.CylindricalGearMeshPowerFlow))
        return value

    @property
    def connection_analysis_cases(self) -> 'List[_3780.CylindricalGearMeshPowerFlow]':
        '''List[CylindricalGearMeshPowerFlow]: 'ConnectionAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConnectionAnalysisCases, constructor.new(_3780.CylindricalGearMeshPowerFlow))
        return value



'''_1239.py

CycloidalDiscModificationsSpecification
'''


from mastapy._internal import constructor, enum_with_selected_value_runtime, conversion
from mastapy.cycloidal import _1240, _1234
from mastapy.math_utility import _1315
from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_CYCLOIDAL_DISC_MODIFICATIONS_SPECIFICATION = python_net_import('SMT.MastaAPI.Cycloidal', 'CycloidalDiscModificationsSpecification')


__docformat__ = 'restructuredtext en'
__all__ = ('CycloidalDiscModificationsSpecification',)


class CycloidalDiscModificationsSpecification(_0.APIBase):
    '''CycloidalDiscModificationsSpecification

    This is a mastapy class.
    '''

    TYPE = _CYCLOIDAL_DISC_MODIFICATIONS_SPECIFICATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CycloidalDiscModificationsSpecification.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def generating_wheel_diameter_modification(self) -> 'float':
        '''float: 'GeneratingWheelDiameterModification' is the original name of this property.'''

        return self.wrapped.GeneratingWheelDiameterModification

    @generating_wheel_diameter_modification.setter
    def generating_wheel_diameter_modification(self, value: 'float'):
        self.wrapped.GeneratingWheelDiameterModification = float(value) if value else 0.0

    @property
    def generating_wheel_centre_circle_diameter_modification(self) -> 'float':
        '''float: 'GeneratingWheelCentreCircleDiameterModification' is the original name of this property.'''

        return self.wrapped.GeneratingWheelCentreCircleDiameterModification

    @generating_wheel_centre_circle_diameter_modification.setter
    def generating_wheel_centre_circle_diameter_modification(self, value: 'float'):
        self.wrapped.GeneratingWheelCentreCircleDiameterModification = float(value) if value else 0.0

    @property
    def angular_offset_modification(self) -> 'float':
        '''float: 'AngularOffsetModification' is the original name of this property.'''

        return self.wrapped.AngularOffsetModification

    @angular_offset_modification.setter
    def angular_offset_modification(self, value: 'float'):
        self.wrapped.AngularOffsetModification = float(value) if value else 0.0

    @property
    def specify_measured_profile_modification(self) -> 'bool':
        '''bool: 'SpecifyMeasuredProfileModification' is the original name of this property.'''

        return self.wrapped.SpecifyMeasuredProfileModification

    @specify_measured_profile_modification.setter
    def specify_measured_profile_modification(self, value: 'bool'):
        self.wrapped.SpecifyMeasuredProfileModification = bool(value) if value else False

    @property
    def direction_of_measured_modifications(self) -> '_1240.DirectionOfMeasuredModifications':
        '''DirectionOfMeasuredModifications: 'DirectionOfMeasuredModifications' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.DirectionOfMeasuredModifications)
        return constructor.new(_1240.DirectionOfMeasuredModifications)(value) if value else None

    @direction_of_measured_modifications.setter
    def direction_of_measured_modifications(self, value: '_1240.DirectionOfMeasuredModifications'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.DirectionOfMeasuredModifications = value

    @property
    def measured_profile_modification(self) -> '_1315.Vector2DListAccessor':
        '''Vector2DListAccessor: 'MeasuredProfileModification' is the original name of this property.'''

        return constructor.new(_1315.Vector2DListAccessor)(self.wrapped.MeasuredProfileModification) if self.wrapped.MeasuredProfileModification else None

    @measured_profile_modification.setter
    def measured_profile_modification(self, value: '_1315.Vector2DListAccessor'):
        value = value.wrapped if value else None
        self.wrapped.MeasuredProfileModification = value

    @property
    def crowning_specification_method(self) -> '_1234.CrowningSpecificationMethod':
        '''CrowningSpecificationMethod: 'CrowningSpecificationMethod' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.CrowningSpecificationMethod)
        return constructor.new(_1234.CrowningSpecificationMethod)(value) if value else None

    @crowning_specification_method.setter
    def crowning_specification_method(self, value: '_1234.CrowningSpecificationMethod'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.CrowningSpecificationMethod = value

    @property
    def crowning_radius(self) -> 'float':
        '''float: 'CrowningRadius' is the original name of this property.'''

        return self.wrapped.CrowningRadius

    @crowning_radius.setter
    def crowning_radius(self, value: 'float'):
        self.wrapped.CrowningRadius = float(value) if value else 0.0

    @property
    def distance_to_where_crowning_starts_from_lobe_centre(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'DistanceToWhereCrowningStartsFromLobeCentre' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.DistanceToWhereCrowningStartsFromLobeCentre) if self.wrapped.DistanceToWhereCrowningStartsFromLobeCentre else None

    @distance_to_where_crowning_starts_from_lobe_centre.setter
    def distance_to_where_crowning_starts_from_lobe_centre(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.DistanceToWhereCrowningStartsFromLobeCentre = value

    @property
    def coefficient_for_logarithmic_crowning(self) -> 'float':
        '''float: 'CoefficientForLogarithmicCrowning' is the original name of this property.'''

        return self.wrapped.CoefficientForLogarithmicCrowning

    @coefficient_for_logarithmic_crowning.setter
    def coefficient_for_logarithmic_crowning(self, value: 'float'):
        self.wrapped.CoefficientForLogarithmicCrowning = float(value) if value else 0.0



'''_1367.py

LoadCaseOverrideOption
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_LOAD_CASE_OVERRIDE_OPTION = python_net_import('SMT.MastaAPI.Utility', 'LoadCaseOverrideOption')


__docformat__ = 'restructuredtext en'
__all__ = ('LoadCaseOverrideOption',)


class LoadCaseOverrideOption(Enum):
    '''LoadCaseOverrideOption

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _LOAD_CASE_OVERRIDE_OPTION

    __hash__ = None

    LOAD_CASE_SETTING = 0
    YES = 1
    NO = 2


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


LoadCaseOverrideOption.__setattr__ = __enum_setattr
LoadCaseOverrideOption.__delattr__ = __enum_delattr



'''_2603.py

CylindricalPlanetGearCompoundSystemDeflection
'''


from typing import List

from mastapy.system_model.analyses_and_results.system_deflections import _2452
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.system_deflections.compound import _2600
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_PLANET_GEAR_COMPOUND_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections.Compound', 'CylindricalPlanetGearCompoundSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalPlanetGearCompoundSystemDeflection',)


class CylindricalPlanetGearCompoundSystemDeflection(_2600.CylindricalGearCompoundSystemDeflection):
    '''CylindricalPlanetGearCompoundSystemDeflection

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_PLANET_GEAR_COMPOUND_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalPlanetGearCompoundSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_analysis_cases_ready(self) -> 'List[_2452.CylindricalPlanetGearSystemDeflection]':
        '''List[CylindricalPlanetGearSystemDeflection]: 'ComponentAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCasesReady, constructor.new(_2452.CylindricalPlanetGearSystemDeflection))
        return value

    @property
    def component_analysis_cases(self) -> 'List[_2452.CylindricalPlanetGearSystemDeflection]':
        '''List[CylindricalPlanetGearSystemDeflection]: 'ComponentAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCases, constructor.new(_2452.CylindricalPlanetGearSystemDeflection))
        return value



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._817 import WormGearLoadCase
    from ._818 import WormGearSetLoadCase
    from ._819 import WormMeshLoadCase



'''_948.py

CylindricalGearCuttingOptions
'''


from mastapy._internal.implicit import enum_with_selected_value, list_with_selected_item
from mastapy.gears.gear_designs.cylindrical import (
    _987, _944, _946, _960,
    _1012, _968
)
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy._internal import enum_with_selected_value_runtime, conversion, constructor
from mastapy._internal.cast_exception import CastException
from mastapy.gears.manufacturing.cylindrical import _564
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_CUTTING_OPTIONS = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Cylindrical', 'CylindricalGearCuttingOptions')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGearCuttingOptions',)


class CylindricalGearCuttingOptions(_0.APIBase):
    '''CylindricalGearCuttingOptions

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_GEAR_CUTTING_OPTIONS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalGearCuttingOptions.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def geometry_specification_type(self) -> 'enum_with_selected_value.EnumWithSelectedValue_GeometrySpecificationType':
        '''enum_with_selected_value.EnumWithSelectedValue_GeometrySpecificationType: 'GeometrySpecificationType' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_GeometrySpecificationType.wrapped_type()
        return enum_with_selected_value_runtime.create(self.wrapped.GeometrySpecificationType, value) if self.wrapped.GeometrySpecificationType else None

    @geometry_specification_type.setter
    def geometry_specification_type(self, value: 'enum_with_selected_value.EnumWithSelectedValue_GeometrySpecificationType.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_GeometrySpecificationType.implicit_type()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.GeometrySpecificationType = value

    @property
    def use_design_default_toleranced_measurement(self) -> 'bool':
        '''bool: 'UseDesignDefaultTolerancedMeasurement' is the original name of this property.'''

        return self.wrapped.UseDesignDefaultTolerancedMeasurement

    @use_design_default_toleranced_measurement.setter
    def use_design_default_toleranced_measurement(self, value: 'bool'):
        self.wrapped.UseDesignDefaultTolerancedMeasurement = bool(value) if value else False

    @property
    def thickness_for_analyses(self) -> 'list_with_selected_item.ListWithSelectedItem_str':
        '''list_with_selected_item.ListWithSelectedItem_str: 'ThicknessForAnalyses' is the original name of this property.'''

        return constructor.new(list_with_selected_item.ListWithSelectedItem_str)(self.wrapped.ThicknessForAnalyses) if self.wrapped.ThicknessForAnalyses else None

    @thickness_for_analyses.setter
    def thickness_for_analyses(self, value: 'list_with_selected_item.ListWithSelectedItem_str.implicit_type()'):
        wrapper_type = list_with_selected_item.ListWithSelectedItem_str.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_str.implicit_type()
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else None)
        self.wrapped.ThicknessForAnalyses = value

    @property
    def cylindrical_gear_cutter(self) -> '_944.CylindricalGearAbstractRack':
        '''CylindricalGearAbstractRack: 'CylindricalGearCutter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _944.CylindricalGearAbstractRack.TYPE not in self.wrapped.CylindricalGearCutter.__class__.__mro__:
            raise CastException('Failed to cast cylindrical_gear_cutter to CylindricalGearAbstractRack. Expected: {}.'.format(self.wrapped.CylindricalGearCutter.__class__.__qualname__))

        return constructor.new_override(self.wrapped.CylindricalGearCutter.__class__)(self.wrapped.CylindricalGearCutter) if self.wrapped.CylindricalGearCutter else None

    @property
    def cylindrical_gear_cutter_of_type_cylindrical_gear_basic_rack(self) -> '_946.CylindricalGearBasicRack':
        '''CylindricalGearBasicRack: 'CylindricalGearCutter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _946.CylindricalGearBasicRack.TYPE not in self.wrapped.CylindricalGearCutter.__class__.__mro__:
            raise CastException('Failed to cast cylindrical_gear_cutter to CylindricalGearBasicRack. Expected: {}.'.format(self.wrapped.CylindricalGearCutter.__class__.__qualname__))

        return constructor.new_override(self.wrapped.CylindricalGearCutter.__class__)(self.wrapped.CylindricalGearCutter) if self.wrapped.CylindricalGearCutter else None

    @property
    def cylindrical_gear_cutter_of_type_cylindrical_gear_pinion_type_cutter(self) -> '_960.CylindricalGearPinionTypeCutter':
        '''CylindricalGearPinionTypeCutter: 'CylindricalGearCutter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _960.CylindricalGearPinionTypeCutter.TYPE not in self.wrapped.CylindricalGearCutter.__class__.__mro__:
            raise CastException('Failed to cast cylindrical_gear_cutter to CylindricalGearPinionTypeCutter. Expected: {}.'.format(self.wrapped.CylindricalGearCutter.__class__.__qualname__))

        return constructor.new_override(self.wrapped.CylindricalGearCutter.__class__)(self.wrapped.CylindricalGearCutter) if self.wrapped.CylindricalGearCutter else None

    @property
    def cylindrical_gear_cutter_of_type_standard_rack(self) -> '_1012.StandardRack':
        '''StandardRack: 'CylindricalGearCutter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1012.StandardRack.TYPE not in self.wrapped.CylindricalGearCutter.__class__.__mro__:
            raise CastException('Failed to cast cylindrical_gear_cutter to StandardRack. Expected: {}.'.format(self.wrapped.CylindricalGearCutter.__class__.__qualname__))

        return constructor.new_override(self.wrapped.CylindricalGearCutter.__class__)(self.wrapped.CylindricalGearCutter) if self.wrapped.CylindricalGearCutter else None

    @property
    def manufacturing_configuration_selection(self) -> '_968.CylindricalGearSetManufacturingConfigurationSelection':
        '''CylindricalGearSetManufacturingConfigurationSelection: 'ManufacturingConfigurationSelection' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_968.CylindricalGearSetManufacturingConfigurationSelection)(self.wrapped.ManufacturingConfigurationSelection) if self.wrapped.ManufacturingConfigurationSelection else None

    @property
    def manufacturing_configuration(self) -> '_564.CylindricalGearManufacturingConfig':
        '''CylindricalGearManufacturingConfig: 'ManufacturingConfiguration' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_564.CylindricalGearManufacturingConfig)(self.wrapped.ManufacturingConfiguration) if self.wrapped.ManufacturingConfiguration else None



'''_693.py

CutterShapeDefinition
'''


from typing import List

from mastapy._internal import constructor, conversion
from mastapy.gears.manufacturing.cylindrical.cutters import (
    _683, _677, _678, _679,
    _680, _682, _684, _685,
    _688
)
from mastapy._internal.cast_exception import CastException
from mastapy.gears.manufacturing.cylindrical.cutters.tangibles import _699
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_CUTTER_SHAPE_DEFINITION = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Cylindrical.Cutters.Tangibles', 'CutterShapeDefinition')


__docformat__ = 'restructuredtext en'
__all__ = ('CutterShapeDefinition',)


class CutterShapeDefinition(_0.APIBase):
    '''CutterShapeDefinition

    This is a mastapy class.
    '''

    TYPE = _CUTTER_SHAPE_DEFINITION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CutterShapeDefinition.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def normal_pitch(self) -> 'float':
        '''float: 'NormalPitch' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NormalPitch

    @property
    def normal_module(self) -> 'float':
        '''float: 'NormalModule' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NormalModule

    @property
    def normal_pressure_angle(self) -> 'float':
        '''float: 'NormalPressureAngle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NormalPressureAngle

    @property
    def design(self) -> '_683.CylindricalGearRealCutterDesign':
        '''CylindricalGearRealCutterDesign: 'Design' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _683.CylindricalGearRealCutterDesign.TYPE not in self.wrapped.Design.__class__.__mro__:
            raise CastException('Failed to cast design to CylindricalGearRealCutterDesign. Expected: {}.'.format(self.wrapped.Design.__class__.__qualname__))

        return constructor.new_override(self.wrapped.Design.__class__)(self.wrapped.Design) if self.wrapped.Design else None

    @property
    def design_of_type_cylindrical_gear_form_grinding_wheel(self) -> '_677.CylindricalGearFormGrindingWheel':
        '''CylindricalGearFormGrindingWheel: 'Design' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _677.CylindricalGearFormGrindingWheel.TYPE not in self.wrapped.Design.__class__.__mro__:
            raise CastException('Failed to cast design to CylindricalGearFormGrindingWheel. Expected: {}.'.format(self.wrapped.Design.__class__.__qualname__))

        return constructor.new_override(self.wrapped.Design.__class__)(self.wrapped.Design) if self.wrapped.Design else None

    @property
    def design_of_type_cylindrical_gear_grinding_worm(self) -> '_678.CylindricalGearGrindingWorm':
        '''CylindricalGearGrindingWorm: 'Design' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _678.CylindricalGearGrindingWorm.TYPE not in self.wrapped.Design.__class__.__mro__:
            raise CastException('Failed to cast design to CylindricalGearGrindingWorm. Expected: {}.'.format(self.wrapped.Design.__class__.__qualname__))

        return constructor.new_override(self.wrapped.Design.__class__)(self.wrapped.Design) if self.wrapped.Design else None

    @property
    def design_of_type_cylindrical_gear_hob_design(self) -> '_679.CylindricalGearHobDesign':
        '''CylindricalGearHobDesign: 'Design' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _679.CylindricalGearHobDesign.TYPE not in self.wrapped.Design.__class__.__mro__:
            raise CastException('Failed to cast design to CylindricalGearHobDesign. Expected: {}.'.format(self.wrapped.Design.__class__.__qualname__))

        return constructor.new_override(self.wrapped.Design.__class__)(self.wrapped.Design) if self.wrapped.Design else None

    @property
    def design_of_type_cylindrical_gear_plunge_shaver(self) -> '_680.CylindricalGearPlungeShaver':
        '''CylindricalGearPlungeShaver: 'Design' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _680.CylindricalGearPlungeShaver.TYPE not in self.wrapped.Design.__class__.__mro__:
            raise CastException('Failed to cast design to CylindricalGearPlungeShaver. Expected: {}.'.format(self.wrapped.Design.__class__.__qualname__))

        return constructor.new_override(self.wrapped.Design.__class__)(self.wrapped.Design) if self.wrapped.Design else None

    @property
    def design_of_type_cylindrical_gear_rack_design(self) -> '_682.CylindricalGearRackDesign':
        '''CylindricalGearRackDesign: 'Design' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _682.CylindricalGearRackDesign.TYPE not in self.wrapped.Design.__class__.__mro__:
            raise CastException('Failed to cast design to CylindricalGearRackDesign. Expected: {}.'.format(self.wrapped.Design.__class__.__qualname__))

        return constructor.new_override(self.wrapped.Design.__class__)(self.wrapped.Design) if self.wrapped.Design else None

    @property
    def design_of_type_cylindrical_gear_shaper(self) -> '_684.CylindricalGearShaper':
        '''CylindricalGearShaper: 'Design' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _684.CylindricalGearShaper.TYPE not in self.wrapped.Design.__class__.__mro__:
            raise CastException('Failed to cast design to CylindricalGearShaper. Expected: {}.'.format(self.wrapped.Design.__class__.__qualname__))

        return constructor.new_override(self.wrapped.Design.__class__)(self.wrapped.Design) if self.wrapped.Design else None

    @property
    def design_of_type_cylindrical_gear_shaver(self) -> '_685.CylindricalGearShaver':
        '''CylindricalGearShaver: 'Design' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _685.CylindricalGearShaver.TYPE not in self.wrapped.Design.__class__.__mro__:
            raise CastException('Failed to cast design to CylindricalGearShaver. Expected: {}.'.format(self.wrapped.Design.__class__.__qualname__))

        return constructor.new_override(self.wrapped.Design.__class__)(self.wrapped.Design) if self.wrapped.Design else None

    @property
    def design_of_type_involute_cutter_design(self) -> '_688.InvoluteCutterDesign':
        '''InvoluteCutterDesign: 'Design' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _688.InvoluteCutterDesign.TYPE not in self.wrapped.Design.__class__.__mro__:
            raise CastException('Failed to cast design to InvoluteCutterDesign. Expected: {}.'.format(self.wrapped.Design.__class__.__qualname__))

        return constructor.new_override(self.wrapped.Design.__class__)(self.wrapped.Design) if self.wrapped.Design else None

    @property
    def fillet_points(self) -> 'List[_699.NamedPoint]':
        '''List[NamedPoint]: 'FilletPoints' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.FilletPoints, constructor.new(_699.NamedPoint))
        return value

    @property
    def main_blade_points(self) -> 'List[_699.NamedPoint]':
        '''List[NamedPoint]: 'MainBladePoints' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.MainBladePoints, constructor.new(_699.NamedPoint))
        return value



'''_1954.py

ContourDrawStyle
'''


from mastapy.utility.enums import _1570
from mastapy._internal import enum_with_selected_value_runtime, constructor, conversion
from mastapy.system_model.drawing import _1964, _1960
from mastapy.geometry import _275
from mastapy._internal.python_net import python_net_import

_CONTOUR_DRAW_STYLE = python_net_import('SMT.MastaAPI.SystemModel.Drawing', 'ContourDrawStyle')


__docformat__ = 'restructuredtext en'
__all__ = ('ContourDrawStyle',)


class ContourDrawStyle(_275.DrawStyleBase):
    '''ContourDrawStyle

    This is a mastapy class.
    '''

    TYPE = _CONTOUR_DRAW_STYLE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ContourDrawStyle.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def contour(self) -> '_1570.ThreeDViewContourOption':
        '''ThreeDViewContourOption: 'Contour' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.Contour)
        return constructor.new(_1570.ThreeDViewContourOption)(value) if value else None

    @contour.setter
    def contour(self, value: '_1570.ThreeDViewContourOption'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.Contour = value

    @property
    def show_local_maxima(self) -> 'bool':
        '''bool: 'ShowLocalMaxima' is the original name of this property.'''

        return self.wrapped.ShowLocalMaxima

    @show_local_maxima.setter
    def show_local_maxima(self, value: 'bool'):
        self.wrapped.ShowLocalMaxima = bool(value) if value else False

    @property
    def minimum_peak_value_displacement(self) -> 'float':
        '''float: 'MinimumPeakValueDisplacement' is the original name of this property.'''

        return self.wrapped.MinimumPeakValueDisplacement

    @minimum_peak_value_displacement.setter
    def minimum_peak_value_displacement(self, value: 'float'):
        self.wrapped.MinimumPeakValueDisplacement = float(value) if value else 0.0

    @property
    def minimum_peak_value_stress(self) -> 'float':
        '''float: 'MinimumPeakValueStress' is the original name of this property.'''

        return self.wrapped.MinimumPeakValueStress

    @minimum_peak_value_stress.setter
    def minimum_peak_value_stress(self, value: 'float'):
        self.wrapped.MinimumPeakValueStress = float(value) if value else 0.0

    @property
    def deflection_scaling(self) -> '_1964.ScalingDrawStyle':
        '''ScalingDrawStyle: 'DeflectionScaling' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1964.ScalingDrawStyle)(self.wrapped.DeflectionScaling) if self.wrapped.DeflectionScaling else None

    @property
    def model_view_options(self) -> '_1960.ModelViewOptionsDrawStyle':
        '''ModelViewOptionsDrawStyle: 'ModelViewOptions' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1960.ModelViewOptionsDrawStyle)(self.wrapped.ModelViewOptions) if self.wrapped.ModelViewOptions else None



'''_2222.py

BevelDifferentialGear
'''


from mastapy.gears.gear_designs.bevel import _1109
from mastapy._internal import constructor
from mastapy.gears.gear_designs.zerol_bevel import _890
from mastapy._internal.cast_exception import CastException
from mastapy.gears.gear_designs.straight_bevel_diff import _899
from mastapy.gears.gear_designs.straight_bevel import _903
from mastapy.gears.gear_designs.spiral_bevel import _907
from mastapy.system_model.part_model.gears import _2226
from mastapy._internal.python_net import python_net_import

_BEVEL_DIFFERENTIAL_GEAR = python_net_import('SMT.MastaAPI.SystemModel.PartModel.Gears', 'BevelDifferentialGear')


__docformat__ = 'restructuredtext en'
__all__ = ('BevelDifferentialGear',)


class BevelDifferentialGear(_2226.BevelGear):
    '''BevelDifferentialGear

    This is a mastapy class.
    '''

    TYPE = _BEVEL_DIFFERENTIAL_GEAR

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BevelDifferentialGear.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def bevel_gear_design(self) -> '_1109.BevelGearDesign':
        '''BevelGearDesign: 'BevelGearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1109.BevelGearDesign.TYPE not in self.wrapped.BevelGearDesign.__class__.__mro__:
            raise CastException('Failed to cast bevel_gear_design to BevelGearDesign. Expected: {}.'.format(self.wrapped.BevelGearDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.BevelGearDesign.__class__)(self.wrapped.BevelGearDesign) if self.wrapped.BevelGearDesign else None

    @property
    def bevel_gear_design_of_type_zerol_bevel_gear_design(self) -> '_890.ZerolBevelGearDesign':
        '''ZerolBevelGearDesign: 'BevelGearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _890.ZerolBevelGearDesign.TYPE not in self.wrapped.BevelGearDesign.__class__.__mro__:
            raise CastException('Failed to cast bevel_gear_design to ZerolBevelGearDesign. Expected: {}.'.format(self.wrapped.BevelGearDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.BevelGearDesign.__class__)(self.wrapped.BevelGearDesign) if self.wrapped.BevelGearDesign else None

    @property
    def bevel_gear_design_of_type_straight_bevel_diff_gear_design(self) -> '_899.StraightBevelDiffGearDesign':
        '''StraightBevelDiffGearDesign: 'BevelGearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _899.StraightBevelDiffGearDesign.TYPE not in self.wrapped.BevelGearDesign.__class__.__mro__:
            raise CastException('Failed to cast bevel_gear_design to StraightBevelDiffGearDesign. Expected: {}.'.format(self.wrapped.BevelGearDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.BevelGearDesign.__class__)(self.wrapped.BevelGearDesign) if self.wrapped.BevelGearDesign else None

    @property
    def bevel_gear_design_of_type_straight_bevel_gear_design(self) -> '_903.StraightBevelGearDesign':
        '''StraightBevelGearDesign: 'BevelGearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _903.StraightBevelGearDesign.TYPE not in self.wrapped.BevelGearDesign.__class__.__mro__:
            raise CastException('Failed to cast bevel_gear_design to StraightBevelGearDesign. Expected: {}.'.format(self.wrapped.BevelGearDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.BevelGearDesign.__class__)(self.wrapped.BevelGearDesign) if self.wrapped.BevelGearDesign else None

    @property
    def bevel_gear_design_of_type_spiral_bevel_gear_design(self) -> '_907.SpiralBevelGearDesign':
        '''SpiralBevelGearDesign: 'BevelGearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _907.SpiralBevelGearDesign.TYPE not in self.wrapped.BevelGearDesign.__class__.__mro__:
            raise CastException('Failed to cast bevel_gear_design to SpiralBevelGearDesign. Expected: {}.'.format(self.wrapped.BevelGearDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.BevelGearDesign.__class__)(self.wrapped.BevelGearDesign) if self.wrapped.BevelGearDesign else None



'''_372.py

KlingelnbergCycloPalloidSpiralBevelGearSetRating
'''


from typing import List

from mastapy.gears.gear_designs.klingelnberg_spiral_bevel import _913
from mastapy._internal import constructor, conversion
from mastapy.gears.rating.klingelnberg_spiral_bevel import _370, _371
from mastapy.gears.rating.klingelnberg_conical import _378
from mastapy._internal.python_net import python_net_import

_KLINGELNBERG_CYCLO_PALLOID_SPIRAL_BEVEL_GEAR_SET_RATING = python_net_import('SMT.MastaAPI.Gears.Rating.KlingelnbergSpiralBevel', 'KlingelnbergCycloPalloidSpiralBevelGearSetRating')


__docformat__ = 'restructuredtext en'
__all__ = ('KlingelnbergCycloPalloidSpiralBevelGearSetRating',)


class KlingelnbergCycloPalloidSpiralBevelGearSetRating(_378.KlingelnbergCycloPalloidConicalGearSetRating):
    '''KlingelnbergCycloPalloidSpiralBevelGearSetRating

    This is a mastapy class.
    '''

    TYPE = _KLINGELNBERG_CYCLO_PALLOID_SPIRAL_BEVEL_GEAR_SET_RATING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'KlingelnbergCycloPalloidSpiralBevelGearSetRating.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_set(self) -> '_913.KlingelnbergCycloPalloidSpiralBevelGearSetDesign':
        '''KlingelnbergCycloPalloidSpiralBevelGearSetDesign: 'KlingelnbergCycloPalloidSpiralBevelGearSet' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_913.KlingelnbergCycloPalloidSpiralBevelGearSetDesign)(self.wrapped.KlingelnbergCycloPalloidSpiralBevelGearSet) if self.wrapped.KlingelnbergCycloPalloidSpiralBevelGearSet else None

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_mesh_ratings(self) -> 'List[_370.KlingelnbergCycloPalloidSpiralBevelGearMeshRating]':
        '''List[KlingelnbergCycloPalloidSpiralBevelGearMeshRating]: 'KlingelnbergCycloPalloidSpiralBevelMeshRatings' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.KlingelnbergCycloPalloidSpiralBevelMeshRatings, constructor.new(_370.KlingelnbergCycloPalloidSpiralBevelGearMeshRating))
        return value

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_ratings(self) -> 'List[_371.KlingelnbergCycloPalloidSpiralBevelGearRating]':
        '''List[KlingelnbergCycloPalloidSpiralBevelGearRating]: 'KlingelnbergCycloPalloidSpiralBevelGearRatings' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.KlingelnbergCycloPalloidSpiralBevelGearRatings, constructor.new(_371.KlingelnbergCycloPalloidSpiralBevelGearRating))
        return value



'''_1696.py

InternalClearance
'''


from mastapy._internal import constructor
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_INTERNAL_CLEARANCE = python_net_import('SMT.MastaAPI.Bearings.BearingResults.Rolling', 'InternalClearance')


__docformat__ = 'restructuredtext en'
__all__ = ('InternalClearance',)


class InternalClearance(_0.APIBase):
    '''InternalClearance

    This is a mastapy class.
    '''

    TYPE = _INTERNAL_CLEARANCE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'InternalClearance.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def radial(self) -> 'float':
        '''float: 'Radial' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Radial

    @property
    def axial(self) -> 'float':
        '''float: 'Axial' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Axial



'''_226.py

GeneralTransmissionProperties
'''


from mastapy.materials import (
    _255, _229, _258, _259,
    _225, _257, _215
)
from mastapy._internal import enum_with_selected_value_runtime, constructor, conversion
from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_GENERAL_TRANSMISSION_PROPERTIES = python_net_import('SMT.MastaAPI.Materials', 'GeneralTransmissionProperties')


__docformat__ = 'restructuredtext en'
__all__ = ('GeneralTransmissionProperties',)


class GeneralTransmissionProperties(_0.APIBase):
    '''GeneralTransmissionProperties

    This is a mastapy class.
    '''

    TYPE = _GENERAL_TRANSMISSION_PROPERTIES

    __hash__ = None

    def __init__(self, instance_to_wrap: 'GeneralTransmissionProperties.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def transmission_application(self) -> '_255.TransmissionApplications':
        '''TransmissionApplications: 'TransmissionApplication' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.TransmissionApplication)
        return constructor.new(_255.TransmissionApplications)(value) if value else None

    @transmission_application.setter
    def transmission_application(self, value: '_255.TransmissionApplications'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.TransmissionApplication = value

    @property
    def zero_speed_tolerance(self) -> 'float':
        '''float: 'ZeroSpeedTolerance' is the original name of this property.'''

        return self.wrapped.ZeroSpeedTolerance

    @zero_speed_tolerance.setter
    def zero_speed_tolerance(self, value: 'float'):
        self.wrapped.ZeroSpeedTolerance = float(value) if value else 0.0

    @property
    def iso2812007_safety_factor_requirement(self) -> 'float':
        '''float: 'ISO2812007SafetyFactorRequirement' is the original name of this property.'''

        return self.wrapped.ISO2812007SafetyFactorRequirement

    @iso2812007_safety_factor_requirement.setter
    def iso2812007_safety_factor_requirement(self, value: 'float'):
        self.wrapped.ISO2812007SafetyFactorRequirement = float(value) if value else 0.0

    @property
    def isots162812008_safety_factor_requirement(self) -> 'float':
        '''float: 'ISOTS162812008SafetyFactorRequirement' is the original name of this property.'''

        return self.wrapped.ISOTS162812008SafetyFactorRequirement

    @isots162812008_safety_factor_requirement.setter
    def isots162812008_safety_factor_requirement(self, value: 'float'):
        self.wrapped.ISOTS162812008SafetyFactorRequirement = float(value) if value else 0.0

    @property
    def thrust_spherical_roller_bearings_iso762006_static_safety_factor_limit(self) -> 'float':
        '''float: 'ThrustSphericalRollerBearingsISO762006StaticSafetyFactorLimit' is the original name of this property.'''

        return self.wrapped.ThrustSphericalRollerBearingsISO762006StaticSafetyFactorLimit

    @thrust_spherical_roller_bearings_iso762006_static_safety_factor_limit.setter
    def thrust_spherical_roller_bearings_iso762006_static_safety_factor_limit(self, value: 'float'):
        self.wrapped.ThrustSphericalRollerBearingsISO762006StaticSafetyFactorLimit = float(value) if value else 0.0

    @property
    def drawn_cup_needle_roller_bearings_iso762006_static_safety_factor_limit(self) -> 'float':
        '''float: 'DrawnCupNeedleRollerBearingsISO762006StaticSafetyFactorLimit' is the original name of this property.'''

        return self.wrapped.DrawnCupNeedleRollerBearingsISO762006StaticSafetyFactorLimit

    @drawn_cup_needle_roller_bearings_iso762006_static_safety_factor_limit.setter
    def drawn_cup_needle_roller_bearings_iso762006_static_safety_factor_limit(self, value: 'float'):
        self.wrapped.DrawnCupNeedleRollerBearingsISO762006StaticSafetyFactorLimit = float(value) if value else 0.0

    @property
    def bearing_iso762006_static_safety_factor_limit(self) -> '_229.ISO76StaticSafetyFactorLimits':
        '''ISO76StaticSafetyFactorLimits: 'BearingISO762006StaticSafetyFactorLimit' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.BearingISO762006StaticSafetyFactorLimit)
        return constructor.new(_229.ISO76StaticSafetyFactorLimits)(value) if value else None

    @bearing_iso762006_static_safety_factor_limit.setter
    def bearing_iso762006_static_safety_factor_limit(self, value: '_229.ISO76StaticSafetyFactorLimits'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.BearingISO762006StaticSafetyFactorLimit = value

    @property
    def include_ansiabma_ratings(self) -> 'bool':
        '''bool: 'IncludeANSIABMARatings' is the original name of this property.'''

        return self.wrapped.IncludeANSIABMARatings

    @include_ansiabma_ratings.setter
    def include_ansiabma_ratings(self, value: 'bool'):
        self.wrapped.IncludeANSIABMARatings = bool(value) if value else False

    @property
    def minimum_static_safety_factor_for_maximum_contact_stress(self) -> 'float':
        '''float: 'MinimumStaticSafetyFactorForMaximumContactStress' is the original name of this property.'''

        return self.wrapped.MinimumStaticSafetyFactorForMaximumContactStress

    @minimum_static_safety_factor_for_maximum_contact_stress.setter
    def minimum_static_safety_factor_for_maximum_contact_stress(self, value: 'float'):
        self.wrapped.MinimumStaticSafetyFactorForMaximumContactStress = float(value) if value else 0.0

    @property
    def permissible_track_truncation_ball_bearings(self) -> 'float':
        '''float: 'PermissibleTrackTruncationBallBearings' is the original name of this property.'''

        return self.wrapped.PermissibleTrackTruncationBallBearings

    @permissible_track_truncation_ball_bearings.setter
    def permissible_track_truncation_ball_bearings(self, value: 'float'):
        self.wrapped.PermissibleTrackTruncationBallBearings = float(value) if value else 0.0

    @property
    def maximum_iso762006_static_safety_factor_for_a_loaded_bearing(self) -> 'float':
        '''float: 'MaximumISO762006StaticSafetyFactorForALoadedBearing' is the original name of this property.'''

        return self.wrapped.MaximumISO762006StaticSafetyFactorForALoadedBearing

    @maximum_iso762006_static_safety_factor_for_a_loaded_bearing.setter
    def maximum_iso762006_static_safety_factor_for_a_loaded_bearing(self, value: 'float'):
        self.wrapped.MaximumISO762006StaticSafetyFactorForALoadedBearing = float(value) if value else 0.0

    @property
    def maximum_static_contact_safety_factor_for_loaded_gears_in_a_mesh(self) -> 'float':
        '''float: 'MaximumStaticContactSafetyFactorForLoadedGearsInAMesh' is the original name of this property.'''

        return self.wrapped.MaximumStaticContactSafetyFactorForLoadedGearsInAMesh

    @maximum_static_contact_safety_factor_for_loaded_gears_in_a_mesh.setter
    def maximum_static_contact_safety_factor_for_loaded_gears_in_a_mesh(self, value: 'float'):
        self.wrapped.MaximumStaticContactSafetyFactorForLoadedGearsInAMesh = float(value) if value else 0.0

    @property
    def wind_turbine_standard(self) -> '_258.WindTurbineStandards':
        '''WindTurbineStandards: 'WindTurbineStandard' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.WindTurbineStandard)
        return constructor.new(_258.WindTurbineStandards)(value) if value else None

    @wind_turbine_standard.setter
    def wind_turbine_standard(self, value: '_258.WindTurbineStandards'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.WindTurbineStandard = value

    @property
    def maximum_bearing_life_modification_factor(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'MaximumBearingLifeModificationFactor' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.MaximumBearingLifeModificationFactor) if self.wrapped.MaximumBearingLifeModificationFactor else None

    @maximum_bearing_life_modification_factor.setter
    def maximum_bearing_life_modification_factor(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.MaximumBearingLifeModificationFactor = value

    @property
    def driving_machine_characteristics(self) -> '_259.WorkingCharacteristics':
        '''WorkingCharacteristics: 'DrivingMachineCharacteristics' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.DrivingMachineCharacteristics)
        return constructor.new(_259.WorkingCharacteristics)(value) if value else None

    @driving_machine_characteristics.setter
    def driving_machine_characteristics(self, value: '_259.WorkingCharacteristics'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.DrivingMachineCharacteristics = value

    @property
    def driven_machine_characteristics(self) -> '_259.WorkingCharacteristics':
        '''WorkingCharacteristics: 'DrivenMachineCharacteristics' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.DrivenMachineCharacteristics)
        return constructor.new(_259.WorkingCharacteristics)(value) if value else None

    @driven_machine_characteristics.setter
    def driven_machine_characteristics(self, value: '_259.WorkingCharacteristics'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.DrivenMachineCharacteristics = value

    @property
    def gearing_type(self) -> '_225.GearingTypes':
        '''GearingTypes: 'GearingType' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.GearingType)
        return constructor.new(_225.GearingTypes)(value) if value else None

    @gearing_type.setter
    def gearing_type(self, value: '_225.GearingTypes'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.GearingType = value

    @property
    def application_factor(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'ApplicationFactor' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.ApplicationFactor) if self.wrapped.ApplicationFactor else None

    @application_factor.setter
    def application_factor(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.ApplicationFactor = value

    @property
    def agma_over_load_factor(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'AGMAOverLoadFactor' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.AGMAOverLoadFactor) if self.wrapped.AGMAOverLoadFactor else None

    @agma_over_load_factor.setter
    def agma_over_load_factor(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.AGMAOverLoadFactor = value

    @property
    def safety_factor_against_sliding(self) -> 'float':
        '''float: 'SafetyFactorAgainstSliding' is the original name of this property.'''

        return self.wrapped.SafetyFactorAgainstSliding

    @safety_factor_against_sliding.setter
    def safety_factor_against_sliding(self, value: 'float'):
        self.wrapped.SafetyFactorAgainstSliding = float(value) if value else 0.0

    @property
    def safety_factor_against_plastic_strain(self) -> 'float':
        '''float: 'SafetyFactorAgainstPlasticStrain' is the original name of this property.'''

        return self.wrapped.SafetyFactorAgainstPlasticStrain

    @safety_factor_against_plastic_strain.setter
    def safety_factor_against_plastic_strain(self, value: 'float'):
        self.wrapped.SafetyFactorAgainstPlasticStrain = float(value) if value else 0.0

    @property
    def required_safety_factor_for_cvt_belt_clamping_force(self) -> 'float':
        '''float: 'RequiredSafetyFactorForCVTBeltClampingForce' is the original name of this property.'''

        return self.wrapped.RequiredSafetyFactorForCVTBeltClampingForce

    @required_safety_factor_for_cvt_belt_clamping_force.setter
    def required_safety_factor_for_cvt_belt_clamping_force(self, value: 'float'):
        self.wrapped.RequiredSafetyFactorForCVTBeltClampingForce = float(value) if value else 0.0

    @property
    def minimum_force_for_bearing_to_be_considered_loaded(self) -> 'float':
        '''float: 'MinimumForceForBearingToBeConsideredLoaded' is the original name of this property.'''

        return self.wrapped.MinimumForceForBearingToBeConsideredLoaded

    @minimum_force_for_bearing_to_be_considered_loaded.setter
    def minimum_force_for_bearing_to_be_considered_loaded(self, value: 'float'):
        self.wrapped.MinimumForceForBearingToBeConsideredLoaded = float(value) if value else 0.0

    @property
    def minimum_moment_for_bearing_to_be_considered_loaded(self) -> 'float':
        '''float: 'MinimumMomentForBearingToBeConsideredLoaded' is the original name of this property.'''

        return self.wrapped.MinimumMomentForBearingToBeConsideredLoaded

    @minimum_moment_for_bearing_to_be_considered_loaded.setter
    def minimum_moment_for_bearing_to_be_considered_loaded(self, value: 'float'):
        self.wrapped.MinimumMomentForBearingToBeConsideredLoaded = float(value) if value else 0.0

    @property
    def linear_bearings_minimum_radial_stiffness(self) -> 'float':
        '''float: 'LinearBearingsMinimumRadialStiffness' is the original name of this property.'''

        return self.wrapped.LinearBearingsMinimumRadialStiffness

    @linear_bearings_minimum_radial_stiffness.setter
    def linear_bearings_minimum_radial_stiffness(self, value: 'float'):
        self.wrapped.LinearBearingsMinimumRadialStiffness = float(value) if value else 0.0

    @property
    def linear_bearings_minimum_axial_stiffness(self) -> 'float':
        '''float: 'LinearBearingsMinimumAxialStiffness' is the original name of this property.'''

        return self.wrapped.LinearBearingsMinimumAxialStiffness

    @linear_bearings_minimum_axial_stiffness.setter
    def linear_bearings_minimum_axial_stiffness(self, value: 'float'):
        self.wrapped.LinearBearingsMinimumAxialStiffness = float(value) if value else 0.0

    @property
    def linear_bearings_minimum_tilt_stiffness(self) -> 'float':
        '''float: 'LinearBearingsMinimumTiltStiffness' is the original name of this property.'''

        return self.wrapped.LinearBearingsMinimumTiltStiffness

    @linear_bearings_minimum_tilt_stiffness.setter
    def linear_bearings_minimum_tilt_stiffness(self, value: 'float'):
        self.wrapped.LinearBearingsMinimumTiltStiffness = float(value) if value else 0.0

    @property
    def non_linear_bearings_minimum_radial_stiffness(self) -> 'float':
        '''float: 'NonLinearBearingsMinimumRadialStiffness' is the original name of this property.'''

        return self.wrapped.NonLinearBearingsMinimumRadialStiffness

    @non_linear_bearings_minimum_radial_stiffness.setter
    def non_linear_bearings_minimum_radial_stiffness(self, value: 'float'):
        self.wrapped.NonLinearBearingsMinimumRadialStiffness = float(value) if value else 0.0

    @property
    def non_linear_bearings_minimum_axial_stiffness(self) -> 'float':
        '''float: 'NonLinearBearingsMinimumAxialStiffness' is the original name of this property.'''

        return self.wrapped.NonLinearBearingsMinimumAxialStiffness

    @non_linear_bearings_minimum_axial_stiffness.setter
    def non_linear_bearings_minimum_axial_stiffness(self, value: 'float'):
        self.wrapped.NonLinearBearingsMinimumAxialStiffness = float(value) if value else 0.0

    @property
    def non_linear_bearings_minimum_tilt_stiffness(self) -> 'float':
        '''float: 'NonLinearBearingsMinimumTiltStiffness' is the original name of this property.'''

        return self.wrapped.NonLinearBearingsMinimumTiltStiffness

    @non_linear_bearings_minimum_tilt_stiffness.setter
    def non_linear_bearings_minimum_tilt_stiffness(self, value: 'float'):
        self.wrapped.NonLinearBearingsMinimumTiltStiffness = float(value) if value else 0.0

    @property
    def energy_convergence_absolute_tolerance(self) -> 'float':
        '''float: 'EnergyConvergenceAbsoluteTolerance' is the original name of this property.'''

        return self.wrapped.EnergyConvergenceAbsoluteTolerance

    @energy_convergence_absolute_tolerance.setter
    def energy_convergence_absolute_tolerance(self, value: 'float'):
        self.wrapped.EnergyConvergenceAbsoluteTolerance = float(value) if value else 0.0

    @property
    def power_convergence_tolerance(self) -> 'float':
        '''float: 'PowerConvergenceTolerance' is the original name of this property.'''

        return self.wrapped.PowerConvergenceTolerance

    @power_convergence_tolerance.setter
    def power_convergence_tolerance(self, value: 'float'):
        self.wrapped.PowerConvergenceTolerance = float(value) if value else 0.0

    @property
    def vehicle_dynamics(self) -> '_257.VehicleDynamicsProperties':
        '''VehicleDynamicsProperties: 'VehicleDynamics' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_257.VehicleDynamicsProperties)(self.wrapped.VehicleDynamics) if self.wrapped.VehicleDynamics else None

    @property
    def air_properties(self) -> '_215.AirProperties':
        '''AirProperties: 'AirProperties' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_215.AirProperties)(self.wrapped.AirProperties) if self.wrapped.AirProperties else None



'''_1903.py

PedestalJournalBearing
'''


from mastapy._internal import constructor
from mastapy.bearings.bearing_designs.fluid_film import _1907
from mastapy._internal.python_net import python_net_import

_PEDESTAL_JOURNAL_BEARING = python_net_import('SMT.MastaAPI.Bearings.BearingDesigns.FluidFilm', 'PedestalJournalBearing')


__docformat__ = 'restructuredtext en'
__all__ = ('PedestalJournalBearing',)


class PedestalJournalBearing(_1907.PlainJournalHousing):
    '''PedestalJournalBearing

    This is a mastapy class.
    '''

    TYPE = _PEDESTAL_JOURNAL_BEARING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PedestalJournalBearing.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def pedestal_base_depth(self) -> 'float':
        '''float: 'PedestalBaseDepth' is the original name of this property.'''

        return self.wrapped.PedestalBaseDepth

    @pedestal_base_depth.setter
    def pedestal_base_depth(self, value: 'float'):
        self.wrapped.PedestalBaseDepth = float(value) if value else 0.0



'''_3809.py

MeasurementComponentPowerFlow
'''


from mastapy.system_model.part_model import _2171
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6606
from mastapy.system_model.analyses_and_results.power_flows import _3858
from mastapy._internal.python_net import python_net_import

_MEASUREMENT_COMPONENT_POWER_FLOW = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.PowerFlows', 'MeasurementComponentPowerFlow')


__docformat__ = 'restructuredtext en'
__all__ = ('MeasurementComponentPowerFlow',)


class MeasurementComponentPowerFlow(_3858.VirtualComponentPowerFlow):
    '''MeasurementComponentPowerFlow

    This is a mastapy class.
    '''

    TYPE = _MEASUREMENT_COMPONENT_POWER_FLOW

    __hash__ = None

    def __init__(self, instance_to_wrap: 'MeasurementComponentPowerFlow.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2171.MeasurementComponent':
        '''MeasurementComponent: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2171.MeasurementComponent)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_load_case(self) -> '_6606.MeasurementComponentLoadCase':
        '''MeasurementComponentLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6606.MeasurementComponentLoadCase)(self.wrapped.ComponentLoadCase) if self.wrapped.ComponentLoadCase else None



'''_266.py

OilPumpDetail
'''


from mastapy.materials.efficiency import _267
from mastapy._internal import enum_with_selected_value_runtime, constructor, conversion
from mastapy.math_utility import _1315
from mastapy.utility import _1364
from mastapy._internal.python_net import python_net_import

_OIL_PUMP_DETAIL = python_net_import('SMT.MastaAPI.Materials.Efficiency', 'OilPumpDetail')


__docformat__ = 'restructuredtext en'
__all__ = ('OilPumpDetail',)


class OilPumpDetail(_1364.IndependentReportablePropertiesBase['OilPumpDetail']):
    '''OilPumpDetail

    This is a mastapy class.
    '''

    TYPE = _OIL_PUMP_DETAIL

    __hash__ = None

    def __init__(self, instance_to_wrap: 'OilPumpDetail.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def oil_pump_drive_type(self) -> '_267.OilPumpDriveType':
        '''OilPumpDriveType: 'OilPumpDriveType' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.OilPumpDriveType)
        return constructor.new(_267.OilPumpDriveType)(value) if value else None

    @oil_pump_drive_type.setter
    def oil_pump_drive_type(self, value: '_267.OilPumpDriveType'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.OilPumpDriveType = value

    @property
    def oil_flow_rate_vs_speed(self) -> '_1315.Vector2DListAccessor':
        '''Vector2DListAccessor: 'OilFlowRateVsSpeed' is the original name of this property.'''

        return constructor.new(_1315.Vector2DListAccessor)(self.wrapped.OilFlowRateVsSpeed) if self.wrapped.OilFlowRateVsSpeed else None

    @oil_flow_rate_vs_speed.setter
    def oil_flow_rate_vs_speed(self, value: '_1315.Vector2DListAccessor'):
        value = value.wrapped if value else None
        self.wrapped.OilFlowRateVsSpeed = value

    @property
    def operating_oil_pressure_vs_speed(self) -> '_1315.Vector2DListAccessor':
        '''Vector2DListAccessor: 'OperatingOilPressureVsSpeed' is the original name of this property.'''

        return constructor.new(_1315.Vector2DListAccessor)(self.wrapped.OperatingOilPressureVsSpeed) if self.wrapped.OperatingOilPressureVsSpeed else None

    @operating_oil_pressure_vs_speed.setter
    def operating_oil_pressure_vs_speed(self, value: '_1315.Vector2DListAccessor'):
        value = value.wrapped if value else None
        self.wrapped.OperatingOilPressureVsSpeed = value

    @property
    def oil_pump_efficiency(self) -> 'float':
        '''float: 'OilPumpEfficiency' is the original name of this property.'''

        return self.wrapped.OilPumpEfficiency

    @oil_pump_efficiency.setter
    def oil_pump_efficiency(self, value: 'float'):
        self.wrapped.OilPumpEfficiency = float(value) if value else 0.0

    @property
    def electric_power_consumed_vs_speed(self) -> '_1315.Vector2DListAccessor':
        '''Vector2DListAccessor: 'ElectricPowerConsumedVsSpeed' is the original name of this property.'''

        return constructor.new(_1315.Vector2DListAccessor)(self.wrapped.ElectricPowerConsumedVsSpeed) if self.wrapped.ElectricPowerConsumedVsSpeed else None

    @electric_power_consumed_vs_speed.setter
    def electric_power_consumed_vs_speed(self, value: '_1315.Vector2DListAccessor'):
        value = value.wrapped if value else None
        self.wrapped.ElectricPowerConsumedVsSpeed = value

    @property
    def electric_motor_efficiency(self) -> 'float':
        '''float: 'ElectricMotorEfficiency' is the original name of this property.'''

        return self.wrapped.ElectricMotorEfficiency

    @electric_motor_efficiency.setter
    def electric_motor_efficiency(self, value: 'float'):
        self.wrapped.ElectricMotorEfficiency = float(value) if value else 0.0



'''_386.py

Iso10300FinishingMethods
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_ISO_10300_FINISHING_METHODS = python_net_import('SMT.MastaAPI.Gears.Rating.Iso10300', 'Iso10300FinishingMethods')


__docformat__ = 'restructuredtext en'
__all__ = ('Iso10300FinishingMethods',)


class Iso10300FinishingMethods(Enum):
    '''Iso10300FinishingMethods

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _ISO_10300_FINISHING_METHODS

    __hash__ = None

    NONE = 0
    LAPPED = 1
    GROUND = 2
    HARD_CUT = 3


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


Iso10300FinishingMethods.__setattr__ = __enum_setattr
Iso10300FinishingMethods.__delattr__ = __enum_delattr



'''_1024.py

Usage
'''


from mastapy.gears import _310
from mastapy._internal import enum_with_selected_value_runtime, constructor, conversion
from mastapy.gears.gear_designs.cylindrical import _1011
from mastapy.utility import _1364
from mastapy._internal.python_net import python_net_import

_USAGE = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Cylindrical', 'Usage')


__docformat__ = 'restructuredtext en'
__all__ = ('Usage',)


class Usage(_1364.IndependentReportablePropertiesBase['Usage']):
    '''Usage

    This is a mastapy class.
    '''

    TYPE = _USAGE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'Usage.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def safety_requirement(self) -> '_310.SafetyRequirementsAGMA':
        '''SafetyRequirementsAGMA: 'SafetyRequirement' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.SafetyRequirement)
        return constructor.new(_310.SafetyRequirementsAGMA)(value) if value else None

    @safety_requirement.setter
    def safety_requirement(self, value: '_310.SafetyRequirementsAGMA'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.SafetyRequirement = value

    @property
    def leads_modified(self) -> 'bool':
        '''bool: 'LeadsModified' is the original name of this property.'''

        return self.wrapped.LeadsModified

    @leads_modified.setter
    def leads_modified(self, value: 'bool'):
        self.wrapped.LeadsModified = bool(value) if value else False

    @property
    def improved_gearing(self) -> 'bool':
        '''bool: 'ImprovedGearing' is the original name of this property.'''

        return self.wrapped.ImprovedGearing

    @improved_gearing.setter
    def improved_gearing(self, value: 'bool'):
        self.wrapped.ImprovedGearing = bool(value) if value else False

    @property
    def gearing_is_runin(self) -> 'bool':
        '''bool: 'GearingIsRunin' is the original name of this property.'''

        return self.wrapped.GearingIsRunin

    @gearing_is_runin.setter
    def gearing_is_runin(self, value: 'bool'):
        self.wrapped.GearingIsRunin = bool(value) if value else False

    @property
    def spur_gear_load_sharing_code(self) -> '_1011.SpurGearLoadSharingCodes':
        '''SpurGearLoadSharingCodes: 'SpurGearLoadSharingCode' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.SpurGearLoadSharingCode)
        return constructor.new(_1011.SpurGearLoadSharingCodes)(value) if value else None

    @spur_gear_load_sharing_code.setter
    def spur_gear_load_sharing_code(self, value: '_1011.SpurGearLoadSharingCodes'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.SpurGearLoadSharingCode = value



'''_5455.py

PlanetaryGearSetHarmonicAnalysisOfSingleExcitation
'''


from mastapy.system_model.part_model.gears import _2249
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.harmonic_analyses_single_excitation import _5419
from mastapy._internal.python_net import python_net_import

_PLANETARY_GEAR_SET_HARMONIC_ANALYSIS_OF_SINGLE_EXCITATION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalysesSingleExcitation', 'PlanetaryGearSetHarmonicAnalysisOfSingleExcitation')


__docformat__ = 'restructuredtext en'
__all__ = ('PlanetaryGearSetHarmonicAnalysisOfSingleExcitation',)


class PlanetaryGearSetHarmonicAnalysisOfSingleExcitation(_5419.CylindricalGearSetHarmonicAnalysisOfSingleExcitation):
    '''PlanetaryGearSetHarmonicAnalysisOfSingleExcitation

    This is a mastapy class.
    '''

    TYPE = _PLANETARY_GEAR_SET_HARMONIC_ANALYSIS_OF_SINGLE_EXCITATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PlanetaryGearSetHarmonicAnalysisOfSingleExcitation.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self) -> '_2249.PlanetaryGearSet':
        '''PlanetaryGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2249.PlanetaryGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None



'''_1379.py

InverseUnit
'''


from mastapy.utility.units_and_measurements import _1385
from mastapy._internal.python_net import python_net_import

_INVERSE_UNIT = python_net_import('SMT.MastaAPI.Utility.UnitsAndMeasurements', 'InverseUnit')


__docformat__ = 'restructuredtext en'
__all__ = ('InverseUnit',)


class InverseUnit(_1385.Unit):
    '''InverseUnit

    This is a mastapy class.
    '''

    TYPE = _INVERSE_UNIT

    __hash__ = None

    def __init__(self, instance_to_wrap: 'InverseUnit.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_2922.py

StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponseOnAShaft
'''


from typing import List

from mastapy.system_model.part_model.gears import _2253
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft.compound import _2920, _2921, _2833
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import _2792
from mastapy._internal.python_net import python_net_import

_STRAIGHT_BEVEL_DIFF_GEAR_SET_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE_ON_A_SHAFT = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponsesOnAShaft.Compound', 'StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponseOnAShaft')


__docformat__ = 'restructuredtext en'
__all__ = ('StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponseOnAShaft',)


class StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponseOnAShaft(_2833.BevelGearSetCompoundSteadyStateSynchronousResponseOnAShaft):
    '''StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponseOnAShaft

    This is a mastapy class.
    '''

    TYPE = _STRAIGHT_BEVEL_DIFF_GEAR_SET_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE_ON_A_SHAFT

    __hash__ = None

    def __init__(self, instance_to_wrap: 'StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponseOnAShaft.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2253.StraightBevelDiffGearSet':
        '''StraightBevelDiffGearSet: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2253.StraightBevelDiffGearSet)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def assembly_design(self) -> '_2253.StraightBevelDiffGearSet':
        '''StraightBevelDiffGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2253.StraightBevelDiffGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def straight_bevel_diff_gears_compound_steady_state_synchronous_response_on_a_shaft(self) -> 'List[_2920.StraightBevelDiffGearCompoundSteadyStateSynchronousResponseOnAShaft]':
        '''List[StraightBevelDiffGearCompoundSteadyStateSynchronousResponseOnAShaft]: 'StraightBevelDiffGearsCompoundSteadyStateSynchronousResponseOnAShaft' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.StraightBevelDiffGearsCompoundSteadyStateSynchronousResponseOnAShaft, constructor.new(_2920.StraightBevelDiffGearCompoundSteadyStateSynchronousResponseOnAShaft))
        return value

    @property
    def straight_bevel_diff_meshes_compound_steady_state_synchronous_response_on_a_shaft(self) -> 'List[_2921.StraightBevelDiffGearMeshCompoundSteadyStateSynchronousResponseOnAShaft]':
        '''List[StraightBevelDiffGearMeshCompoundSteadyStateSynchronousResponseOnAShaft]: 'StraightBevelDiffMeshesCompoundSteadyStateSynchronousResponseOnAShaft' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.StraightBevelDiffMeshesCompoundSteadyStateSynchronousResponseOnAShaft, constructor.new(_2921.StraightBevelDiffGearMeshCompoundSteadyStateSynchronousResponseOnAShaft))
        return value

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_2792.StraightBevelDiffGearSetSteadyStateSynchronousResponseOnAShaft]':
        '''List[StraightBevelDiffGearSetSteadyStateSynchronousResponseOnAShaft]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCasesReady, constructor.new(_2792.StraightBevelDiffGearSetSteadyStateSynchronousResponseOnAShaft))
        return value

    @property
    def assembly_analysis_cases(self) -> 'List[_2792.StraightBevelDiffGearSetSteadyStateSynchronousResponseOnAShaft]':
        '''List[StraightBevelDiffGearSetSteadyStateSynchronousResponseOnAShaft]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCases, constructor.new(_2792.StraightBevelDiffGearSetSteadyStateSynchronousResponseOnAShaft))
        return value



'''_248.py

SafetyFactorItem
'''


from mastapy._internal import constructor
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_SAFETY_FACTOR_ITEM = python_net_import('SMT.MastaAPI.Materials', 'SafetyFactorItem')


__docformat__ = 'restructuredtext en'
__all__ = ('SafetyFactorItem',)


class SafetyFactorItem(_0.APIBase):
    '''SafetyFactorItem

    This is a mastapy class.
    '''

    TYPE = _SAFETY_FACTOR_ITEM

    __hash__ = None

    def __init__(self, instance_to_wrap: 'SafetyFactorItem.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def description(self) -> 'str':
        '''str: 'Description' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Description

    @property
    def safety_factor(self) -> 'float':
        '''float: 'SafetyFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SafetyFactor

    @property
    def minimum_required_safety_factor(self) -> 'float':
        '''float: 'MinimumRequiredSafetyFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumRequiredSafetyFactor

    @property
    def reliability(self) -> 'float':
        '''float: 'Reliability' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Reliability

    @property
    def damage(self) -> 'float':
        '''float: 'Damage' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Damage

    @property
    def time_until_failure(self) -> 'float':
        '''float: 'TimeUntilFailure' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TimeUntilFailure



'''_2605.py

DutyCycleEfficiencyResults
'''


from typing import List

from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.system_deflections import _2479
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_DUTY_CYCLE_EFFICIENCY_RESULTS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections.Compound', 'DutyCycleEfficiencyResults')


__docformat__ = 'restructuredtext en'
__all__ = ('DutyCycleEfficiencyResults',)


class DutyCycleEfficiencyResults(_0.APIBase):
    '''DutyCycleEfficiencyResults

    This is a mastapy class.
    '''

    TYPE = _DUTY_CYCLE_EFFICIENCY_RESULTS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'DutyCycleEfficiencyResults.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def energy_input(self) -> 'float':
        '''float: 'EnergyInput' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EnergyInput

    @property
    def energy_lost(self) -> 'float':
        '''float: 'EnergyLost' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EnergyLost

    @property
    def energy_output(self) -> 'float':
        '''float: 'EnergyOutput' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EnergyOutput

    @property
    def efficiency(self) -> 'float':
        '''float: 'Efficiency' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Efficiency

    @property
    def name(self) -> 'str':
        '''str: 'Name' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Name

    @property
    def load_case_overall_efficiency_result(self) -> 'List[_2479.LoadCaseOverallEfficiencyResult]':
        '''List[LoadCaseOverallEfficiencyResult]: 'LoadCaseOverallEfficiencyResult' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.LoadCaseOverallEfficiencyResult, constructor.new(_2479.LoadCaseOverallEfficiencyResult))
        return value



'''_5357.py

GenericClutchEngagementStatus
'''


from typing import Generic, TypeVar

from mastapy._internal import constructor
from mastapy import _0
from mastapy.system_model import _1919
from mastapy._internal.python_net import python_net_import

_GENERIC_CLUTCH_ENGAGEMENT_STATUS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.LoadCaseGroups', 'GenericClutchEngagementStatus')


__docformat__ = 'restructuredtext en'
__all__ = ('GenericClutchEngagementStatus',)


T = TypeVar('T', bound='_1919.DesignEntity')


class GenericClutchEngagementStatus(_0.APIBase, Generic[T]):
    '''GenericClutchEngagementStatus

    This is a mastapy class.

    Generic Types:
        T
    '''

    TYPE = _GENERIC_CLUTCH_ENGAGEMENT_STATUS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'GenericClutchEngagementStatus.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def name(self) -> 'str':
        '''str: 'Name' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Name

    @property
    def unique_name(self) -> 'str':
        '''str: 'UniqueName' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.UniqueName

    @property
    def is_engaged(self) -> 'bool':
        '''bool: 'IsEngaged' is the original name of this property.'''

        return self.wrapped.IsEngaged

    @is_engaged.setter
    def is_engaged(self, value: 'bool'):
        self.wrapped.IsEngaged = bool(value) if value else False



'''_46.py

AnalysisSettingsDatabase
'''


from mastapy.utility.databases import _1576
from mastapy.nodal_analysis import _47
from mastapy._internal.python_net import python_net_import

_ANALYSIS_SETTINGS_DATABASE = python_net_import('SMT.MastaAPI.NodalAnalysis', 'AnalysisSettingsDatabase')


__docformat__ = 'restructuredtext en'
__all__ = ('AnalysisSettingsDatabase',)


class AnalysisSettingsDatabase(_1576.NamedDatabase['_47.AnalysisSettingsObjects']):
    '''AnalysisSettingsDatabase

    This is a mastapy class.
    '''

    TYPE = _ANALYSIS_SETTINGS_DATABASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'AnalysisSettingsDatabase.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_1292.py

FacetedBody
'''


from typing import List

from mastapy.math_utility import _1293
from mastapy._internal import constructor, conversion
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_FACETED_BODY = python_net_import('SMT.MastaAPI.MathUtility', 'FacetedBody')


__docformat__ = 'restructuredtext en'
__all__ = ('FacetedBody',)


class FacetedBody(_0.APIBase):
    '''FacetedBody

    This is a mastapy class.
    '''

    TYPE = _FACETED_BODY

    __hash__ = None

    def __init__(self, instance_to_wrap: 'FacetedBody.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def surfaces(self) -> 'List[_1293.FacetedSurface]':
        '''List[FacetedSurface]: 'Surfaces' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Surfaces, constructor.new(_1293.FacetedSurface))
        return value

    def add_surface(self, vertices: 'List[List[float]]', normals: 'List[List[float]]', facets: 'List[List[int]]'):
        ''' 'AddSurface' is the original name of this method.

        Args:
            vertices (List[List[float]])
            normals (List[List[float]])
            facets (List[List[int]])
        '''

        vertices = conversion.mp_to_pn_objects_in_list(vertices)
        normals = conversion.mp_to_pn_objects_in_list(normals)
        facets = conversion.mp_to_pn_objects_in_list(facets)
        self.wrapped.AddSurface(vertices, normals, facets)



'''_1270.py

AcousticWeighting
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_ACOUSTIC_WEIGHTING = python_net_import('SMT.MastaAPI.MathUtility', 'AcousticWeighting')


__docformat__ = 'restructuredtext en'
__all__ = ('AcousticWeighting',)


class AcousticWeighting(Enum):
    '''AcousticWeighting

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _ACOUSTIC_WEIGHTING

    __hash__ = None

    NONE = 0
    AWEIGHTING = 1
    BWEIGHTING = 2
    CWEIGHTING = 3
    DWEIGHTING = 4


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


AcousticWeighting.__setattr__ = __enum_setattr
AcousticWeighting.__delattr__ = __enum_delattr



'''_6808.py

StraightBevelSunGearAdvancedTimeSteppingAnalysisForModulation
'''


from mastapy.system_model.part_model.gears import _2257
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.system_deflections import _2522
from mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import _6801
from mastapy._internal.python_net import python_net_import

_STRAIGHT_BEVEL_SUN_GEAR_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedTimeSteppingAnalysesForModulation', 'StraightBevelSunGearAdvancedTimeSteppingAnalysisForModulation')


__docformat__ = 'restructuredtext en'
__all__ = ('StraightBevelSunGearAdvancedTimeSteppingAnalysisForModulation',)


class StraightBevelSunGearAdvancedTimeSteppingAnalysisForModulation(_6801.StraightBevelDiffGearAdvancedTimeSteppingAnalysisForModulation):
    '''StraightBevelSunGearAdvancedTimeSteppingAnalysisForModulation

    This is a mastapy class.
    '''

    TYPE = _STRAIGHT_BEVEL_SUN_GEAR_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'StraightBevelSunGearAdvancedTimeSteppingAnalysisForModulation.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2257.StraightBevelSunGear':
        '''StraightBevelSunGear: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2257.StraightBevelSunGear)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def system_deflection_results(self) -> '_2522.StraightBevelSunGearSystemDeflection':
        '''StraightBevelSunGearSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2522.StraightBevelSunGearSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None



'''_7164.py

KlingelnbergCycloPalloidSpiralBevelGearSetCompoundAdvancedSystemDeflection
'''


from typing import List

from mastapy.system_model.part_model.gears import _2248
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.advanced_system_deflections.compound import _7162, _7163, _7158
from mastapy.system_model.analyses_and_results.advanced_system_deflections import _7033
from mastapy._internal.python_net import python_net_import

_KLINGELNBERG_CYCLO_PALLOID_SPIRAL_BEVEL_GEAR_SET_COMPOUND_ADVANCED_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedSystemDeflections.Compound', 'KlingelnbergCycloPalloidSpiralBevelGearSetCompoundAdvancedSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('KlingelnbergCycloPalloidSpiralBevelGearSetCompoundAdvancedSystemDeflection',)


class KlingelnbergCycloPalloidSpiralBevelGearSetCompoundAdvancedSystemDeflection(_7158.KlingelnbergCycloPalloidConicalGearSetCompoundAdvancedSystemDeflection):
    '''KlingelnbergCycloPalloidSpiralBevelGearSetCompoundAdvancedSystemDeflection

    This is a mastapy class.
    '''

    TYPE = _KLINGELNBERG_CYCLO_PALLOID_SPIRAL_BEVEL_GEAR_SET_COMPOUND_ADVANCED_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'KlingelnbergCycloPalloidSpiralBevelGearSetCompoundAdvancedSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2248.KlingelnbergCycloPalloidSpiralBevelGearSet':
        '''KlingelnbergCycloPalloidSpiralBevelGearSet: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2248.KlingelnbergCycloPalloidSpiralBevelGearSet)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def assembly_design(self) -> '_2248.KlingelnbergCycloPalloidSpiralBevelGearSet':
        '''KlingelnbergCycloPalloidSpiralBevelGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2248.KlingelnbergCycloPalloidSpiralBevelGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gears_compound_advanced_system_deflection(self) -> 'List[_7162.KlingelnbergCycloPalloidSpiralBevelGearCompoundAdvancedSystemDeflection]':
        '''List[KlingelnbergCycloPalloidSpiralBevelGearCompoundAdvancedSystemDeflection]: 'KlingelnbergCycloPalloidSpiralBevelGearsCompoundAdvancedSystemDeflection' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.KlingelnbergCycloPalloidSpiralBevelGearsCompoundAdvancedSystemDeflection, constructor.new(_7162.KlingelnbergCycloPalloidSpiralBevelGearCompoundAdvancedSystemDeflection))
        return value

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_meshes_compound_advanced_system_deflection(self) -> 'List[_7163.KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundAdvancedSystemDeflection]':
        '''List[KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundAdvancedSystemDeflection]: 'KlingelnbergCycloPalloidSpiralBevelMeshesCompoundAdvancedSystemDeflection' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.KlingelnbergCycloPalloidSpiralBevelMeshesCompoundAdvancedSystemDeflection, constructor.new(_7163.KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundAdvancedSystemDeflection))
        return value

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_7033.KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection]':
        '''List[KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCasesReady, constructor.new(_7033.KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection))
        return value

    @property
    def assembly_analysis_cases(self) -> 'List[_7033.KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection]':
        '''List[KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCases, constructor.new(_7033.KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection))
        return value



'''_360.py

StraightBevelDiffGearMeshRating
'''


from typing import List

from mastapy._internal import constructor, conversion
from mastapy.gears.gear_designs.straight_bevel_diff import _900
from mastapy.gears.rating.straight_bevel_diff import _363, _361
from mastapy.gears.rating.conical import _491
from mastapy._internal.python_net import python_net_import

_STRAIGHT_BEVEL_DIFF_GEAR_MESH_RATING = python_net_import('SMT.MastaAPI.Gears.Rating.StraightBevelDiff', 'StraightBevelDiffGearMeshRating')


__docformat__ = 'restructuredtext en'
__all__ = ('StraightBevelDiffGearMeshRating',)


class StraightBevelDiffGearMeshRating(_491.ConicalGearMeshRating):
    '''StraightBevelDiffGearMeshRating

    This is a mastapy class.
    '''

    TYPE = _STRAIGHT_BEVEL_DIFF_GEAR_MESH_RATING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'StraightBevelDiffGearMeshRating.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def load_distribution_factor(self) -> 'float':
        '''float: 'LoadDistributionFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LoadDistributionFactor

    @property
    def derating_factor(self) -> 'float':
        '''float: 'DeratingFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DeratingFactor

    @property
    def inertia_factor_bending(self) -> 'float':
        '''float: 'InertiaFactorBending' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.InertiaFactorBending

    @property
    def rating_result(self) -> 'str':
        '''str: 'RatingResult' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RatingResult

    @property
    def straight_bevel_diff_gear_mesh(self) -> '_900.StraightBevelDiffGearMeshDesign':
        '''StraightBevelDiffGearMeshDesign: 'StraightBevelDiffGearMesh' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_900.StraightBevelDiffGearMeshDesign)(self.wrapped.StraightBevelDiffGearMesh) if self.wrapped.StraightBevelDiffGearMesh else None

    @property
    def meshed_gears(self) -> 'List[_363.StraightBevelDiffMeshedGearRating]':
        '''List[StraightBevelDiffMeshedGearRating]: 'MeshedGears' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.MeshedGears, constructor.new(_363.StraightBevelDiffMeshedGearRating))
        return value

    @property
    def gears_in_mesh(self) -> 'List[_363.StraightBevelDiffMeshedGearRating]':
        '''List[StraightBevelDiffMeshedGearRating]: 'GearsInMesh' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.GearsInMesh, constructor.new(_363.StraightBevelDiffMeshedGearRating))
        return value

    @property
    def straight_bevel_diff_gear_ratings(self) -> 'List[_361.StraightBevelDiffGearRating]':
        '''List[StraightBevelDiffGearRating]: 'StraightBevelDiffGearRatings' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.StraightBevelDiffGearRatings, constructor.new(_361.StraightBevelDiffGearRating))
        return value



'''_844.py

CandidateDisplayChoice
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_CANDIDATE_DISPLAY_CHOICE = python_net_import('SMT.MastaAPI.Gears.GearSetParetoOptimiser', 'CandidateDisplayChoice')


__docformat__ = 'restructuredtext en'
__all__ = ('CandidateDisplayChoice',)


class CandidateDisplayChoice(Enum):
    '''CandidateDisplayChoice

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _CANDIDATE_DISPLAY_CHOICE

    __hash__ = None

    ALL_FEASIBLE_CANDIDATES = 0
    CANDIDATES_AFTER_FILTERING = 1
    DOMINANT_CANDIDATES = 2
    CANDIDATES_SELECTED_IN_CHART = 3


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


CandidateDisplayChoice.__setattr__ = __enum_setattr
CandidateDisplayChoice.__delattr__ = __enum_delattr



'''_111.py

StepHalvingTransientSolver
'''


from mastapy.nodal_analysis.system_solvers import _99
from mastapy._internal.python_net import python_net_import

_STEP_HALVING_TRANSIENT_SOLVER = python_net_import('SMT.MastaAPI.NodalAnalysis.SystemSolvers', 'StepHalvingTransientSolver')


__docformat__ = 'restructuredtext en'
__all__ = ('StepHalvingTransientSolver',)


class StepHalvingTransientSolver(_99.InternalTransientSolver):
    '''StepHalvingTransientSolver

    This is a mastapy class.
    '''

    TYPE = _STEP_HALVING_TRANSIENT_SOLVER

    __hash__ = None

    def __init__(self, instance_to_wrap: 'StepHalvingTransientSolver.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_1257.py

DetailedBoltDesign
'''


from typing import List

from mastapy.bolts import (
    _1263, _1260, _1255, _1248,
    _1246, _1250
)
from mastapy._internal import enum_with_selected_value_runtime, constructor, conversion
from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy._internal.python_net import python_net_import
from mastapy._math.vector_3d import Vector3D
from mastapy._internal.cast_exception import CastException
from mastapy import _0

_DATABASE_WITH_SELECTED_ITEM = python_net_import('SMT.MastaAPI.UtilityGUI.Databases', 'DatabaseWithSelectedItem')
_DETAILED_BOLT_DESIGN = python_net_import('SMT.MastaAPI.Bolts', 'DetailedBoltDesign')


__docformat__ = 'restructuredtext en'
__all__ = ('DetailedBoltDesign',)


class DetailedBoltDesign(_0.APIBase):
    '''DetailedBoltDesign

    This is a mastapy class.
    '''

    TYPE = _DETAILED_BOLT_DESIGN

    __hash__ = None

    def __init__(self, instance_to_wrap: 'DetailedBoltDesign.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def rolled_before_or_after_heat_treatment(self) -> '_1263.RolledBeforeOrAfterHeatTreament':
        '''RolledBeforeOrAfterHeatTreament: 'RolledBeforeOrAfterHeatTreatment' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.RolledBeforeOrAfterHeatTreatment)
        return constructor.new(_1263.RolledBeforeOrAfterHeatTreament)(value) if value else None

    @rolled_before_or_after_heat_treatment.setter
    def rolled_before_or_after_heat_treatment(self, value: '_1263.RolledBeforeOrAfterHeatTreament'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.RolledBeforeOrAfterHeatTreatment = value

    @property
    def number_of_force_transmitting_interfaces(self) -> 'int':
        '''int: 'NumberOfForceTransmittingInterfaces' is the original name of this property.'''

        return self.wrapped.NumberOfForceTransmittingInterfaces

    @number_of_force_transmitting_interfaces.setter
    def number_of_force_transmitting_interfaces(self, value: 'int'):
        self.wrapped.NumberOfForceTransmittingInterfaces = int(value) if value else 0

    @property
    def number_of_torque_transmitting_interfaces(self) -> 'int':
        '''int: 'NumberOfTorqueTransmittingInterfaces' is the original name of this property.'''

        return self.wrapped.NumberOfTorqueTransmittingInterfaces

    @number_of_torque_transmitting_interfaces.setter
    def number_of_torque_transmitting_interfaces(self, value: 'int'):
        self.wrapped.NumberOfTorqueTransmittingInterfaces = int(value) if value else 0

    @property
    def friction_radius(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'FrictionRadius' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.FrictionRadius) if self.wrapped.FrictionRadius else None

    @friction_radius.setter
    def friction_radius(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.FrictionRadius = value

    @property
    def distance_of_bolt_axis_from_central_point(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'DistanceOfBoltAxisFromCentralPoint' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.DistanceOfBoltAxisFromCentralPoint) if self.wrapped.DistanceOfBoltAxisFromCentralPoint else None

    @distance_of_bolt_axis_from_central_point.setter
    def distance_of_bolt_axis_from_central_point(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.DistanceOfBoltAxisFromCentralPoint = value

    @property
    def joint_geometry(self) -> '_1260.JointGeometries':
        '''JointGeometries: 'JointGeometry' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.JointGeometry)
        return constructor.new(_1260.JointGeometries)(value) if value else None

    @joint_geometry.setter
    def joint_geometry(self, value: '_1260.JointGeometries'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.JointGeometry = value

    @property
    def number_of_bolt_sections(self) -> 'int':
        '''int: 'NumberOfBoltSections' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NumberOfBoltSections

    @property
    def washer_thickness(self) -> 'float':
        '''float: 'WasherThickness' is the original name of this property.'''

        return self.wrapped.WasherThickness

    @washer_thickness.setter
    def washer_thickness(self, value: 'float'):
        self.wrapped.WasherThickness = float(value) if value else 0.0

    @property
    def inside_diameter_of_plane_head_bearing_surface(self) -> 'float':
        '''float: 'InsideDiameterOfPlaneHeadBearingSurface' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.InsideDiameterOfPlaneHeadBearingSurface

    @property
    def chamfer_diameter_at_the_clamped_parts(self) -> 'float':
        '''float: 'ChamferDiameterAtTheClampedParts' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ChamferDiameterAtTheClampedParts

    @property
    def distance_of_the_bolt_axis_from_edge_of_interface(self) -> 'float':
        '''float: 'DistanceOfTheBoltAxisFromEdgeOfInterface' is the original name of this property.'''

        return self.wrapped.DistanceOfTheBoltAxisFromEdgeOfInterface

    @distance_of_the_bolt_axis_from_edge_of_interface.setter
    def distance_of_the_bolt_axis_from_edge_of_interface(self, value: 'float'):
        self.wrapped.DistanceOfTheBoltAxisFromEdgeOfInterface = float(value) if value else 0.0

    @property
    def substitutional_outside_diameter_of_basic_solid_at_interface(self) -> 'float':
        '''float: 'SubstitutionalOutsideDiameterOfBasicSolidAtInterface' is the original name of this property.'''

        return self.wrapped.SubstitutionalOutsideDiameterOfBasicSolidAtInterface

    @substitutional_outside_diameter_of_basic_solid_at_interface.setter
    def substitutional_outside_diameter_of_basic_solid_at_interface(self, value: 'float'):
        self.wrapped.SubstitutionalOutsideDiameterOfBasicSolidAtInterface = float(value) if value else 0.0

    @property
    def substitutional_outside_diameter_of_basic_solid(self) -> 'float':
        '''float: 'SubstitutionalOutsideDiameterOfBasicSolid' is the original name of this property.'''

        return self.wrapped.SubstitutionalOutsideDiameterOfBasicSolid

    @substitutional_outside_diameter_of_basic_solid.setter
    def substitutional_outside_diameter_of_basic_solid(self, value: 'float'):
        self.wrapped.SubstitutionalOutsideDiameterOfBasicSolid = float(value) if value else 0.0

    @property
    def nut_chamfer_diameter(self) -> 'float':
        '''float: 'NutChamferDiameter' is the original name of this property.'''

        return self.wrapped.NutChamferDiameter

    @nut_chamfer_diameter.setter
    def nut_chamfer_diameter(self, value: 'float'):
        self.wrapped.NutChamferDiameter = float(value) if value else 0.0

    @property
    def average_outside_diameter_of_clamped_parts(self) -> 'float':
        '''float: 'AverageOutsideDiameterOfClampedParts' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AverageOutsideDiameterOfClampedParts

    @property
    def outside_diameter_of_nut(self) -> 'float':
        '''float: 'OutsideDiameterOfNut' is the original name of this property.'''

        return self.wrapped.OutsideDiameterOfNut

    @outside_diameter_of_nut.setter
    def outside_diameter_of_nut(self, value: 'float'):
        self.wrapped.OutsideDiameterOfNut = float(value) if value else 0.0

    @property
    def bearing_area_diameter_at_the_interface(self) -> 'float':
        '''float: 'BearingAreaDiameterAtTheInterface' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BearingAreaDiameterAtTheInterface

    @property
    def substitutional_bending_length_of_bolt(self) -> 'float':
        '''float: 'SubstitutionalBendingLengthOfBolt' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SubstitutionalBendingLengthOfBolt

    @property
    def length_of_free_loaded_thread(self) -> 'float':
        '''float: 'LengthOfFreeLoadedThread' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LengthOfFreeLoadedThread

    @property
    def minimum_plate_thickness(self) -> 'float':
        '''float: 'MinimumPlateThickness' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumPlateThickness

    @property
    def length_of_deformation_sleeve(self) -> 'float':
        '''float: 'LengthOfDeformationSleeve' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LengthOfDeformationSleeve

    @property
    def length_of_deformation_cone(self) -> 'float':
        '''float: 'LengthOfDeformationCone' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LengthOfDeformationCone

    @property
    def measurement_interface_area_perpendicular_to_width(self) -> 'float':
        '''float: 'MeasurementInterfaceAreaPerpendicularToWidth' is the original name of this property.'''

        return self.wrapped.MeasurementInterfaceAreaPerpendicularToWidth

    @measurement_interface_area_perpendicular_to_width.setter
    def measurement_interface_area_perpendicular_to_width(self, value: 'float'):
        self.wrapped.MeasurementInterfaceAreaPerpendicularToWidth = float(value) if value else 0.0

    @property
    def width(self) -> 'float':
        '''float: 'Width' is the original name of this property.'''

        return self.wrapped.Width

    @width.setter
    def width(self, value: 'float'):
        self.wrapped.Width = float(value) if value else 0.0

    @property
    def counter_bore_depth(self) -> 'float':
        '''float: 'CounterBoreDepth' is the original name of this property.'''

        return self.wrapped.CounterBoreDepth

    @counter_bore_depth.setter
    def counter_bore_depth(self, value: 'float'):
        self.wrapped.CounterBoreDepth = float(value) if value else 0.0

    @property
    def limiting_outside_diameter_maximum_diameter_of_deformation_cone(self) -> 'float':
        '''float: 'LimitingOutsideDiameterMaximumDiameterOfDeformationCone' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LimitingOutsideDiameterMaximumDiameterOfDeformationCone

    @property
    def maximum_outside_diameter_of_deformation_cone(self) -> 'float':
        '''float: 'MaximumOutsideDiameterOfDeformationCone' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumOutsideDiameterOfDeformationCone

    @property
    def is_concentrically_clamped(self) -> 'bool':
        '''bool: 'IsConcentricallyClamped' is the original name of this property.'''

        return self.wrapped.IsConcentricallyClamped

    @is_concentrically_clamped.setter
    def is_concentrically_clamped(self, value: 'bool'):
        self.wrapped.IsConcentricallyClamped = bool(value) if value else False

    @property
    def stress_diameter(self) -> 'float':
        '''float: 'StressDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.StressDiameter

    @property
    def height(self) -> 'float':
        '''float: 'Height' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Height

    @property
    def clamping_length(self) -> 'float':
        '''float: 'ClampingLength' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ClampingLength

    @property
    def minimum_coefficient_of_friction_of_thread(self) -> 'float':
        '''float: 'MinimumCoefficientOfFrictionOfThread' is the original name of this property.'''

        return self.wrapped.MinimumCoefficientOfFrictionOfThread

    @minimum_coefficient_of_friction_of_thread.setter
    def minimum_coefficient_of_friction_of_thread(self, value: 'float'):
        self.wrapped.MinimumCoefficientOfFrictionOfThread = float(value) if value else 0.0

    @property
    def minimum_coefficient_of_friction_of_bearing_area(self) -> 'float':
        '''float: 'MinimumCoefficientOfFrictionOfBearingArea' is the original name of this property.'''

        return self.wrapped.MinimumCoefficientOfFrictionOfBearingArea

    @minimum_coefficient_of_friction_of_bearing_area.setter
    def minimum_coefficient_of_friction_of_bearing_area(self, value: 'float'):
        self.wrapped.MinimumCoefficientOfFrictionOfBearingArea = float(value) if value else 0.0

    @property
    def maximum_coefficient_of_friction_of_thread(self) -> 'float':
        '''float: 'MaximumCoefficientOfFrictionOfThread' is the original name of this property.'''

        return self.wrapped.MaximumCoefficientOfFrictionOfThread

    @maximum_coefficient_of_friction_of_thread.setter
    def maximum_coefficient_of_friction_of_thread(self, value: 'float'):
        self.wrapped.MaximumCoefficientOfFrictionOfThread = float(value) if value else 0.0

    @property
    def maximum_coefficient_of_friction_of_bearing_area(self) -> 'float':
        '''float: 'MaximumCoefficientOfFrictionOfBearingArea' is the original name of this property.'''

        return self.wrapped.MaximumCoefficientOfFrictionOfBearingArea

    @maximum_coefficient_of_friction_of_bearing_area.setter
    def maximum_coefficient_of_friction_of_bearing_area(self, value: 'float'):
        self.wrapped.MaximumCoefficientOfFrictionOfBearingArea = float(value) if value else 0.0

    @property
    def utilization_factor(self) -> 'float':
        '''float: 'UtilizationFactor' is the original name of this property.'''

        return self.wrapped.UtilizationFactor

    @utilization_factor.setter
    def utilization_factor(self, value: 'float'):
        self.wrapped.UtilizationFactor = float(value) if value else 0.0

    @property
    def reduction_coefficient(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'ReductionCoefficient' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.ReductionCoefficient) if self.wrapped.ReductionCoefficient else None

    @reduction_coefficient.setter
    def reduction_coefficient(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.ReductionCoefficient = value

    @property
    def joint_coefficient(self) -> 'float':
        '''float: 'JointCoefficient' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.JointCoefficient

    @property
    def appropriate_minimum_bolt_diameter(self) -> 'float':
        '''float: 'AppropriateMinimumBoltDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AppropriateMinimumBoltDiameter

    @property
    def appropriate_minimum_cross_sectional_area_for_hollow_bolt(self) -> 'float':
        '''float: 'AppropriateMinimumCrossSectionalAreaForHollowBolt' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AppropriateMinimumCrossSectionalAreaForHollowBolt

    @property
    def stress_cross_sectional_area(self) -> 'float':
        '''float: 'StressCrossSectionalArea' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.StressCrossSectionalArea

    @property
    def minimum_bearing_area(self) -> 'float':
        '''float: 'MinimumBearingArea' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumBearingArea

    @property
    def minimum_assembly_bearing_area_of_nut(self) -> 'float':
        '''float: 'MinimumAssemblyBearingAreaOfNut' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumAssemblyBearingAreaOfNut

    @property
    def minimum_assembly_bearing_area_of_head(self) -> 'float':
        '''float: 'MinimumAssemblyBearingAreaOfHead' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumAssemblyBearingAreaOfHead

    @property
    def shearing_area_transverse_loading(self) -> 'float':
        '''float: 'ShearingAreaTransverseLoading' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ShearingAreaTransverseLoading

    @property
    def diameter_of_shearing_cross_section(self) -> 'float':
        '''float: 'DiameterOfShearingCrossSection' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DiameterOfShearingCrossSection

    @property
    def clamped_parts(self) -> 'List[_1255.ClampedSection]':
        '''List[ClampedSection]: 'ClampedParts' is the original name of this property.'''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ClampedParts, constructor.new(_1255.ClampedSection))
        return value

    @clamped_parts.setter
    def clamped_parts(self, value: 'List[_1255.ClampedSection]'):
        value = value if value else None
        value = conversion.mp_to_pn_objects_in_list(value)
        self.wrapped.ClampedParts = value

    @property
    def substitutional_extension_length_of_engaged_thread(self) -> 'float':
        '''float: 'SubstitutionalExtensionLengthOfEngagedThread' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SubstitutionalExtensionLengthOfEngagedThread

    @property
    def cross_section_of_thread(self) -> 'float':
        '''float: 'CrossSectionOfThread' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CrossSectionOfThread

    @property
    def substitutional_extension_length_of_engaged_nut_thread(self) -> 'float':
        '''float: 'SubstitutionalExtensionLengthOfEngagedNutThread' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SubstitutionalExtensionLengthOfEngagedNutThread

    @property
    def nominal_cross_section(self) -> 'float':
        '''float: 'NominalCrossSection' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NominalCrossSection

    @property
    def nominal_cross_section_of_hollow_bolt(self) -> 'float':
        '''float: 'NominalCrossSectionOfHollowBolt' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NominalCrossSectionOfHollowBolt

    @property
    def substitutional_extension_length_of_head(self) -> 'float':
        '''float: 'SubstitutionalExtensionLengthOfHead' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SubstitutionalExtensionLengthOfHead

    @property
    def total_axial_resilience(self) -> 'float':
        '''float: 'TotalAxialResilience' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TotalAxialResilience

    @property
    def section_radii_of_gyration(self) -> 'List[float]':
        '''List[float]: 'SectionRadiiOfGyration' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_list_float(self.wrapped.SectionRadiiOfGyration)
        return value

    @property
    def total_bending_resilience(self) -> 'float':
        '''float: 'TotalBendingResilience' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TotalBendingResilience

    @property
    def length_ratio(self) -> 'float':
        '''float: 'LengthRatio' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LengthRatio

    @property
    def outside_diameter_of_bearing_surface_of_washer(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'OutsideDiameterOfBearingSurfaceOfWasher' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.OutsideDiameterOfBearingSurfaceOfWasher) if self.wrapped.OutsideDiameterOfBearingSurfaceOfWasher else None

    @outside_diameter_of_bearing_surface_of_washer.setter
    def outside_diameter_of_bearing_surface_of_washer(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.OutsideDiameterOfBearingSurfaceOfWasher = value

    @property
    def inside_diameter_of_bearing_surface_of_washer(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'InsideDiameterOfBearingSurfaceOfWasher' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.InsideDiameterOfBearingSurfaceOfWasher) if self.wrapped.InsideDiameterOfBearingSurfaceOfWasher else None

    @inside_diameter_of_bearing_surface_of_washer.setter
    def inside_diameter_of_bearing_surface_of_washer(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.InsideDiameterOfBearingSurfaceOfWasher = value

    @property
    def diameter_ratio(self) -> 'float':
        '''float: 'DiameterRatio' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DiameterRatio

    @property
    def substitutional_moment_of_gyration_of_cone(self) -> 'float':
        '''float: 'SubstitutionalMomentOfGyrationOfCone' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SubstitutionalMomentOfGyrationOfCone

    @property
    def moment_of_gyration_of_cross_section_at_minor_thread_diameter(self) -> 'float':
        '''float: 'MomentOfGyrationOfCrossSectionAtMinorThreadDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MomentOfGyrationOfCrossSectionAtMinorThreadDiameter

    @property
    def substitutional_moment_of_gyration_of_sleeve(self) -> 'float':
        '''float: 'SubstitutionalMomentOfGyrationOfSleeve' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SubstitutionalMomentOfGyrationOfSleeve

    @property
    def substitutional_moment_of_gyration_of_plates(self) -> 'float':
        '''float: 'SubstitutionalMomentOfGyrationOfPlates' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SubstitutionalMomentOfGyrationOfPlates

    @property
    def substitutional_moment_of_gyration_of_plates_minus_bolt_area(self) -> 'float':
        '''float: 'SubstitutionalMomentOfGyrationOfPlatesMinusBoltArea' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SubstitutionalMomentOfGyrationOfPlatesMinusBoltArea

    @property
    def limiting_value_of_interface_dsv(self) -> 'float':
        '''float: 'LimitingValueOfInterfaceDSV' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LimitingValueOfInterfaceDSV

    @property
    def limiting_value_of_interface_esv(self) -> 'float':
        '''float: 'LimitingValueOfInterfaceESV' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LimitingValueOfInterfaceESV

    @property
    def limiting_value_of_interface_esv_with_recessed_tapped_hole(self) -> 'float':
        '''float: 'LimitingValueOfInterfaceESVWithRecessedTappedHole' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LimitingValueOfInterfaceESVWithRecessedTappedHole

    @property
    def elastic_bending_resilience_of_concentric_clamped_parts(self) -> 'float':
        '''float: 'ElasticBendingResilienceOfConcentricClampedParts' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ElasticBendingResilienceOfConcentricClampedParts

    @property
    def elastic_bending_resilience_of_clamped_parts(self) -> 'float':
        '''float: 'ElasticBendingResilienceOfClampedParts' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ElasticBendingResilienceOfClampedParts

    @property
    def elastic_resilience_of_clamped_parts(self) -> 'float':
        '''float: 'ElasticResilienceOfClampedParts' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ElasticResilienceOfClampedParts

    @property
    def elastic_resilience_of_clamped_parts_in_operating_state(self) -> 'float':
        '''float: 'ElasticResilienceOfClampedPartsInOperatingState' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ElasticResilienceOfClampedPartsInOperatingState

    @property
    def consider_this_tapped_thread_bolt_as_a_through_bolted_joint(self) -> 'bool':
        '''bool: 'ConsiderThisTappedThreadBoltAsAThroughBoltedJoint' is the original name of this property.'''

        return self.wrapped.ConsiderThisTappedThreadBoltAsAThroughBoltedJoint

    @consider_this_tapped_thread_bolt_as_a_through_bolted_joint.setter
    def consider_this_tapped_thread_bolt_as_a_through_bolted_joint(self, value: 'bool'):
        self.wrapped.ConsiderThisTappedThreadBoltAsAThroughBoltedJoint = bool(value) if value else False

    @property
    def deformation_cone_angle(self) -> 'float':
        '''float: 'DeformationConeAngle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DeformationConeAngle

    @property
    def elastic_resilience_of_clamped_parts_eccentric_clamping(self) -> 'float':
        '''float: 'ElasticResilienceOfClampedPartsEccentricClamping' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ElasticResilienceOfClampedPartsEccentricClamping

    @property
    def elastic_resilience_of_clamped_parts_eccentric_loading(self) -> 'float':
        '''float: 'ElasticResilienceOfClampedPartsEccentricLoading' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ElasticResilienceOfClampedPartsEccentricLoading

    @property
    def inside_diameter_of_head_bearing_area(self) -> 'float':
        '''float: 'InsideDiameterOfHeadBearingArea' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.InsideDiameterOfHeadBearingArea

    @property
    def average_surface_roughness(self) -> 'float':
        '''float: 'AverageSurfaceRoughness' is the original name of this property.'''

        return self.wrapped.AverageSurfaceRoughness

    @average_surface_roughness.setter
    def average_surface_roughness(self, value: 'float'):
        self.wrapped.AverageSurfaceRoughness = float(value) if value else 0.0

    @property
    def minimum_coefficient_of_friction_at_interface(self) -> 'float':
        '''float: 'MinimumCoefficientOfFrictionAtInterface' is the original name of this property.'''

        return self.wrapped.MinimumCoefficientOfFrictionAtInterface

    @minimum_coefficient_of_friction_at_interface.setter
    def minimum_coefficient_of_friction_at_interface(self, value: 'float'):
        self.wrapped.MinimumCoefficientOfFrictionAtInterface = float(value) if value else 0.0

    @property
    def name(self) -> 'str':
        '''str: 'Name' is the original name of this property.'''

        return self.wrapped.Name

    @name.setter
    def name(self, value: 'str'):
        self.wrapped.Name = str(value) if value else None

    @property
    def diameter_for_the_specified_standard_size(self) -> 'float':
        '''float: 'DiameterForTheSpecifiedStandardSize' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DiameterForTheSpecifiedStandardSize

    @property
    def sealing_area(self) -> 'float':
        '''float: 'SealingArea' is the original name of this property.'''

        return self.wrapped.SealingArea

    @sealing_area.setter
    def sealing_area(self, value: 'float'):
        self.wrapped.SealingArea = float(value) if value else 0.0

    @property
    def edit_bolt_geometry(self) -> 'str':
        '''str: 'EditBoltGeometry' is the original name of this property.'''

        return self.wrapped.EditBoltGeometry.SelectedItemName

    @edit_bolt_geometry.setter
    def edit_bolt_geometry(self, value: 'str'):
        self.wrapped.EditBoltGeometry.SetSelectedItem(str(value) if value else None)

    @property
    def edit_bolt_material(self) -> 'str':
        '''str: 'EditBoltMaterial' is the original name of this property.'''

        return self.wrapped.EditBoltMaterial.SelectedItemName

    @edit_bolt_material.setter
    def edit_bolt_material(self, value: 'str'):
        self.wrapped.EditBoltMaterial.SetSelectedItem(str(value) if value else None)

    @property
    def edit_nut_material(self) -> 'str':
        '''str: 'EditNutMaterial' is the original name of this property.'''

        return self.wrapped.EditNutMaterial.SelectedItemName

    @edit_nut_material.setter
    def edit_nut_material(self, value: 'str'):
        self.wrapped.EditNutMaterial.SetSelectedItem(str(value) if value else None)

    @property
    def edit_tapped_thread_material(self) -> 'str':
        '''str: 'EditTappedThreadMaterial' is the original name of this property.'''

        return self.wrapped.EditTappedThreadMaterial.SelectedItemName

    @edit_tapped_thread_material.setter
    def edit_tapped_thread_material(self, value: 'str'):
        self.wrapped.EditTappedThreadMaterial.SetSelectedItem(str(value) if value else None)

    @property
    def bolt_geometry(self) -> '_1248.BoltGeometry':
        '''BoltGeometry: 'BoltGeometry' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1248.BoltGeometry)(self.wrapped.BoltGeometry) if self.wrapped.BoltGeometry else None

    @property
    def orientation(self) -> 'Vector3D':
        '''Vector3D: 'Orientation' is the original name of this property.'''

        value = conversion.pn_to_mp_vector3d(self.wrapped.Orientation)
        return value

    @orientation.setter
    def orientation(self, value: 'Vector3D'):
        value = value if value else None
        value = conversion.mp_to_pn_vector3d(value)
        self.wrapped.Orientation = value

    @property
    def material_of_nut(self) -> '_1246.BoltedJointMaterial':
        '''BoltedJointMaterial: 'MaterialOfNut' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1246.BoltedJointMaterial.TYPE not in self.wrapped.MaterialOfNut.__class__.__mro__:
            raise CastException('Failed to cast material_of_nut to BoltedJointMaterial. Expected: {}.'.format(self.wrapped.MaterialOfNut.__class__.__qualname__))

        return constructor.new_override(self.wrapped.MaterialOfNut.__class__)(self.wrapped.MaterialOfNut) if self.wrapped.MaterialOfNut else None

    @property
    def material_of_bolt(self) -> '_1250.BoltMaterial':
        '''BoltMaterial: 'MaterialOfBolt' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1250.BoltMaterial)(self.wrapped.MaterialOfBolt) if self.wrapped.MaterialOfBolt else None

    @property
    def material_of_tapped_thread(self) -> '_1246.BoltedJointMaterial':
        '''BoltedJointMaterial: 'MaterialOfTappedThread' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1246.BoltedJointMaterial.TYPE not in self.wrapped.MaterialOfTappedThread.__class__.__mro__:
            raise CastException('Failed to cast material_of_tapped_thread to BoltedJointMaterial. Expected: {}.'.format(self.wrapped.MaterialOfTappedThread.__class__.__qualname__))

        return constructor.new_override(self.wrapped.MaterialOfTappedThread.__class__)(self.wrapped.MaterialOfTappedThread) if self.wrapped.MaterialOfTappedThread else None

    @property
    def clamped_sections(self) -> 'List[_1255.ClampedSection]':
        '''List[ClampedSection]: 'ClampedSections' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ClampedSections, constructor.new(_1255.ClampedSection))
        return value

    @property
    def report_names(self) -> 'List[str]':
        '''List[str]: 'ReportNames' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ReportNames, str)
        return value

    def output_default_report_to(self, file_path: 'str'):
        ''' 'OutputDefaultReportTo' is the original name of this method.

        Args:
            file_path (str)
        '''

        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else None)

    def get_default_report_with_encoded_images(self) -> 'str':
        ''' 'GetDefaultReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        '''

        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    def output_active_report_to(self, file_path: 'str'):
        ''' 'OutputActiveReportTo' is the original name of this method.

        Args:
            file_path (str)
        '''

        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else None)

    def output_active_report_as_text_to(self, file_path: 'str'):
        ''' 'OutputActiveReportAsTextTo' is the original name of this method.

        Args:
            file_path (str)
        '''

        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else None)

    def get_active_report_with_encoded_images(self) -> 'str':
        ''' 'GetActiveReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        '''

        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    def output_named_report_to(self, report_name: 'str', file_path: 'str'):
        ''' 'OutputNamedReportTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        '''

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(report_name if report_name else None, file_path if file_path else None)

    def output_named_report_as_masta_report(self, report_name: 'str', file_path: 'str'):
        ''' 'OutputNamedReportAsMastaReport' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        '''

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(report_name if report_name else None, file_path if file_path else None)

    def output_named_report_as_text_to(self, report_name: 'str', file_path: 'str'):
        ''' 'OutputNamedReportAsTextTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        '''

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(report_name if report_name else None, file_path if file_path else None)

    def get_named_report_with_encoded_images(self, report_name: 'str') -> 'str':
        ''' 'GetNamedReportWithEncodedImages' is the original name of this method.

        Args:
            report_name (str)

        Returns:
            str
        '''

        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(report_name if report_name else None)
        return method_result



'''_2437.py

CycloidalAssemblySystemDeflection
'''


from typing import List

from mastapy.system_model.part_model.cycloidal import _2275
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6538
from mastapy.system_model.analyses_and_results.power_flows import _3775
from mastapy.system_model.analyses_and_results.system_deflections import _2497, _2508
from mastapy._internal.python_net import python_net_import

_CYCLOIDAL_ASSEMBLY_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections', 'CycloidalAssemblySystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('CycloidalAssemblySystemDeflection',)


class CycloidalAssemblySystemDeflection(_2508.SpecialisedAssemblySystemDeflection):
    '''CycloidalAssemblySystemDeflection

    This is a mastapy class.
    '''

    TYPE = _CYCLOIDAL_ASSEMBLY_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CycloidalAssemblySystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self) -> '_2275.CycloidalAssembly':
        '''CycloidalAssembly: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2275.CycloidalAssembly)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_load_case(self) -> '_6538.CycloidalAssemblyLoadCase':
        '''CycloidalAssemblyLoadCase: 'AssemblyLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6538.CycloidalAssemblyLoadCase)(self.wrapped.AssemblyLoadCase) if self.wrapped.AssemblyLoadCase else None

    @property
    def power_flow_results(self) -> '_3775.CycloidalAssemblyPowerFlow':
        '''CycloidalAssemblyPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_3775.CycloidalAssemblyPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None

    @property
    def ring_pins_to_disc_connections(self) -> 'List[_2497.RingPinsToDiscConnectionSystemDeflection]':
        '''List[RingPinsToDiscConnectionSystemDeflection]: 'RingPinsToDiscConnections' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.RingPinsToDiscConnections, constructor.new(_2497.RingPinsToDiscConnectionSystemDeflection))
        return value



'''_7250.py

PythonCommand
'''


from typing import Generic, TypeVar

from mastapy._internal import constructor
from mastapy.scripting import _7251
from mastapy._internal.python_net import python_net_import

_PYTHON_COMMAND = python_net_import('SMT.MastaAPIUtility.Scripting', 'PythonCommand')


__docformat__ = 'restructuredtext en'
__all__ = ('PythonCommand',)


T = TypeVar('T')


class PythonCommand(_7251.ScriptingCommand, Generic[T]):
    '''PythonCommand

    This is a mastapy class.

    Generic Types:
        T
    '''

    TYPE = _PYTHON_COMMAND

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PythonCommand.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    def execute(self):
        ''' 'Execute' is the original name of this method.'''

        self.wrapped.Execute()
